__all__ = ['tty',     # libgtktty
	   'xmhtml',  # libgtk-xmhtml
	   'ui',      # libgnomeui
	   'zvt',     # libzvt
	   'applet',  # panel applets
	   'capplet', # control center capplets
	   'config', 'file', 'help', 'history',
	   'metadata', 'mime', 'score', 'url', 'util'] # libgnome

# set app_id and app_version where other modules can find it easily ...

import sys, string
if len(sys.argv) > 0:
	app_id = sys.argv[0][string.rfind(sys.argv[0], '/')+1:]
	if app_id[-3:] == '.py':
		app_id = app_id[:-3]
	elif app_id[-4:] in ('.pyc', '.pyo'):
		app_id = app_id[:-4]
else:
	app_id = 'unknown'
del sys, string

app_version = "0.0"

gnomelib_init_called = 0
gnome_init_called = 0



# python-gnome-dial
# Vincent Renardias <vincent@ldsol.com>, 1999/09/10

from gtk import *
from gnome.ui import *
from GDK import *

def quit_app(foo):
	#app.set_float("DialValue=", adjustment) 	
	window.hide()
	window.destroy()
	mainquit

app = GnomeApp('gnomedial')
#app.config_get_float("DialValue=")

window = GtkWindow(type='toplevel')
window.connect('destroy', mainquit)
window.set_title('range controls')
window.set_border_width(10)

box1 = GtkVBox(0,10)
window.add(box1)
box1.show()

box2 = GtkVBox(0,10)
box2.set_border_width(0)
box1.pack_start(box2, 1, 1, 0)
box2.show

adjustment = GtkAdjustment(0.0, 0.0, 101.0, 0.1, 1.0, 1.0)

scale = GtkHScale(adjustment)
scale.set_usize(150,30)
scale.set_update_policy('delayed')
scale.set_digits(1)
scale.set_draw_value(1)
box2.pack_start(scale, 1, 1, 0)
scale.show()

scrollbar = GtkHScrollbar(adjustment)
scrollbar.set_update_policy('continuous')
box2.pack_start(scrollbar, 1, 1, 0)
scrollbar.show()

dial = GtkDial(adjustment)
dial.set_update_policy('continuous')
box2.pack_start(dial, 1, 1, 0)
dial.show()

separator = GtkHSeparator()
box1.pack_start(separator, 0, 1, 0)
separator.show()

box2 = GtkVBox(0, 10)
box2.set_border_width(10)
box1.pack_start(box2, 0, 1, 0)
box2.show()

button = GtkButton('close')
#button.connect('clicked', lambda foo: window.destroy())
button.connect('clicked', quit_app)
box2.pack_start(button, 1, 1, 0)
button.set_flags(CAN_DEFAULT)
button.grab_default()

button.show()

window.show_all()

mainloop()




import sys; _sys = sys; del sys
import gtk; _gtk = gtk; del gtk
import _gnomeui, gnome

if not gnome.gnome_init_called:
	_gnomeui.gnome_init(gnome.app_id, gnome.app_version)
	_gnomeui.gtk_ted_set_app_name(gnome.app_id)
	gnome.gnome_init_called = 1
	# gnome_init calls gnomelib_init
	gnome.gnomelib_init_called = 1
del gnome

# lets get our constants ...
from uiconsts import *

_obj2inst = _gtk._obj2inst
_filtprops = _gtk._filtprops

class GnomeDialog(_gtk.GtkWindow):
	get_type = _gnomeui.gnome_dialog_get_type
	def __init__(self, title='', b1=None, b2=None, b3=None, b4=None,
		     b5=None, b6=None, b7=None, b8=None, b9=None, b10=None,
		     _obj=None):
		if _obj: self._o = _obj; return
		buttons = filter(lambda x: x, (b1,b2,b3,b4,b5,b6,b7,b8,b9,b10))
		self._o = apply(_gnomeui.gnome_dialog_new, (title,) + buttons)
	def __getattr__(self, attr):
		attrs = {
			"vbox": _gnomeui.gnome_dialog_get_vbox,
		}
		if attrs.has_key(attr):
			return _obj2inst(attrs[attr](self._o))
		return _gtk.GtkWindow.__getattr__(self, attr)
	def set_parent(self, parent):
		_gnomeui.gnome_dialog_set_parent(self._o, parent._o)
	def run(self):
		return _gnomeui.gnome_dialog_run(self._o)
	def run_and_close(self):
		return _gnomeui.gnome_dialog_run_and_close(self._o)
	def button_connect(self, button, callback, *extra):
		_gnomeui.gnome_dialog_button_connect(self._o, button, callback,
						     extra)
	def set_default(self, button):
		_gnomeui.gnome_dialog_set_default(self._o, button)
	def set_sensitive(self, button, setting):
		_gnomeui.gnome_dialog_set_sensitive(self._o, button, setting)
	def set_destroy(self, self_destruct):
		print "Deprecated -- use set_close"
		_gnomeui.gnome_dialog_set_destroy(self._o, self_destruct)
	def set_accelerator(self, button, ac_key, ac_mods):
		_gnomeui.gnome_dialog_set_accelerator(self._o, button, ac_key,
						      ac_mods)
	def close(self, obj=None):
		_gnomeui.gnome_dialog_close(self._o)
	def close_hides(self, just_hide):
		_gnomeui.gnome_dialog_close_hides(self._o, just_hide)
	def set_close(self, click_closes):
		_gnomeui.gnome_dialog_set_close(self._o, click_closes)
	def editable_enters(self, editable):
		_gnomeui.gnome_dialog_editable_enters(self._o, editable._o)
	def append_buttons(self, b1=None, b2=None, b3=None, b4=None, b5=None,
			   b6=None, b7=None, b8=None, b9=None, b10=None):
		buttons = filter(lambda x: x, (b1,b2,b3,b4,b5,b6,b7,b8,b9,b10))
		apply(_gnomeui.gnome_dialog_append_buttons, (self._o,)+buttons)
	def append_button(self, name):
		_gnomeui.gnome_dialog_append_button(self._o, name)
	def append_button_with_pixmap(self, name, pixmap):
		_gnomeui.gnome_dialog_append_button_with_pixmap(self._o, name,
								pixmap)
_gtk._name2cls['GnomeDialog'] = GnomeDialog

# these are wrappers for the convenience functions.  They really return
# GnomeDialog's.
class GnomeOkDialog(GnomeDialog):
	def __init__(self, msg, parent=None):
		if parent:
			self._o = _gnomeui.gnome_ok_dialog_parented(msg,
								    parent._o)
		else:
			self._o = _gnomeui.gnome_ok_dialog(msg)
class GnomeErrorDialog(GnomeDialog):
	def __init__(self, error, parent=None):
		if parent:
			self._o = _gnomeui.gnome_error_dialog_parented(
				error, parent._o)
		else:
			self._o = _gnomeui.gnome_error_dialog(error)
class GnomeWarningDialog(GnomeDialog):
	def __init__(self, warning, parent=None):
		if parent:
			self._o = _gnomeui.gnome_warning_dialog_parented(
				warning, parent._o)
		else:
			self._o = _gnomeui.gnome_warning_dialog(warning)
class GnomeQuestionDialog(GnomeDialog):
	def __init__(self, question, cb, parent=None):
		if parent:
			self._o = _gnomeui.gnome_question_dialog_parented(
				question, cb, parent._o)
		else:
			self._o = _gnomeui.gnome_question_dialog(question, cb)
class GnomeOkCancelDialog(GnomeDialog):
	def __init__(self, message, cb, parent=None):
		if parent:
			self._o = _gnomeui.gnome_ok_cancel_dialog_parented(
				message, cb, parent._o)
		else:
			self._o = _gnomeui.gnome_ok_cancel_dialog(message, cb)
class GnomeRequestDialog(GnomeDialog):
	def __init__(self, password, prompt, default_text, max_length,
		     callback, parent):
		if parent: parent = parent._o
		self._o = _gnomeui.gnome_request_dialog(password, prompt,
							default_text,
							max_length, callback,
							parent)

class GnomeAbout(GnomeDialog):
	get_type = _gnomeui.gnome_about_get_type
	def __init__(self, title=None, version=None, copyright=None, list=[],
		     comments=None, logo=None, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_about_new(title, version, copyright,
						   list, comments, logo)
_gtk._name2cls['GnomeAbout'] = GnomeAbout

class GnomeAnimator(_gtk.GtkWidget):
	get_type = _gnomeui.gnome_animator_get_type
	def __init__(self, width=100, height=100, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_animator_new_with_size(width, height)
	def set_loop_type(self, loop_type):
		_gnomeui.gnome_animator_set_loop_type(self._o, loop_type)
	def get_loop_type(self):
		return _gnomeui.gnome_animator_get_loop_type(self._o)
	def set_playback_direction(self, dir):
		_gnomeui.gnome_animator_set_playback_direction(self._o, dir)
	def get_playback_direction(self):
		return _gnomeui.gnome_animator_get_playback_direction(self._o)
	def append_frame_from_imlib(self, image, xofs, yofs,
				    interval, width=-1, height=-1):
		if (width, height) == (-1, -1):
			return _gnomeui.gnome_animator_append_frame_from_imlib(
				self._o, image._im, xofs, yofs, interval)
		return _gnomeui.gnome_animator_append_frame_from_imlib_at_size(
			self._o, image._im, xofs, yofs, interval, width,height)
	def append_frame_from_file(self, file, xofs, yofs,
				   interval, width=-1, height=-1):
		if (width, height) == (-1, -1):
			return _gnomeui.gnome_animator_append_frame_from_file(
				self._o, file, xofs, yofs, interval)
		return _gnomeui.gnome_animator_append_frame_from_file_at_size(
			self._o, file, xofs, yofs, interval, width, height)
	def append_frames_from_imlib(self, image, xofs, yofs,
				     interval, xunit, width=-1, height=-1):
	       if (width, height) == (-1, -1):
		       return _gnomeui.gnome_animator_append_frames_from_imlib(
			     self._o, image._im, xofs, yofs, interval, xunit)
	       return _gnomeui.gnome_animator_append_frames_from_imlib_at_size(
			self._o, image._im, xofs, yofs, interval, xunit,
			width, height)
	def append_frames_from_file(self, file, xofs, yofs,
				   interval, xunit, width=-1, height=-1):
		if (width, height) == (-1, -1):
			return _gnomeui.gnome_animator_append_frames_from_file(
				self._o, file, xofs, yofs, interval, xunit)
		return _gnomeui.gnome_animator_append_frames_from_file_at_size(
			self._o, file, xofs, yofs, interval,xunit,width,height)
	def append_frame_from_gnome_pixmap(self, pixmap, xofs, yofs, interval):
		return _gnomeui.gnome_animator_append_frame_from_gnome_pixmap(
			self._o, pixmap._o, xofs, yofs, interval)
	def start(self):
		_gnomeui.gnome_animator_start(self._o)
	def stop(self):
		_gnomeui.gnome_animator_stop(self._o)
	def advance(self, num):
		return _gnomeui.gnome_animator_advance(self._o, num)
	def goto_frame(self, frame_num):
		_gnomeui.gnome_animator_goto_frame(self._o, frame_num)
	def get_current_frame_number(self):
		return _gnomeui.gnome_animator_get_current_frame(self._o)
	def get_status(self):
		return _gnomeui.gnome_animator_get_status(self._o)
	def set_playback_speed(self, speed):
		_gnomeui.gnome_animator_set_playback_speed(self._o, speed)
	def get_playback_speed(self):
		return _gnomeui.gnome_animator_get_playback_speed(self._o)
_gtk._name2cls['GnomeAnimator'] = GnomeAnimator

class GnomeApp(_gtk.GtkWindow):
	get_type = _gnomeui.gnome_app_get_type
	def __init__(self, appname='', title='', _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_app_new(appname, title)
	def set_menus(self, menubar):
		_gnomeui.gnome_app_set_menus(self._o, menubar._o)
	def set_toolbar(self, toolbar):
		_gnomeui.gnome_app_set_toolbar(self._o, toolbar._o)
	def set_statusbar(self, statusbar):
		_gnomeui.gnome_app_set_statusbar(self._o, statusbar._o)
	def set_statusbar_custom(self, container, statusbar):
		_gnomeui.gnome_app_set_statusbar_custom(self._o, container._o,
							statusbar._o)
	def set_contents(self, contents):
		_gnomeui.gnome_app_set_contents(self._o, contents._o)
	def add_toolbar(self, toolbar, name, behavior, placement, band_num,
			band_position, offset):
		_gnomeui.gnome_app_add_toolbar(self._o, toolbar._o, name,
					       behavior, placement, band_num,
					       band_position, offset)
	def add_docked(self, widget, name, behavior, placement, band_num,
			band_position, offset):
		_gnomeui.gnome_app_add_docked(self._o, widget._o, name,
					      behavior, placement, band_num,
					      band_position, offset)
	def add_dock_item(self, item, placement, band_num, band_position,
			  offset):
		_gnomeui.gnome_app_add_dock_item(self._o, item._o, placement,
						 band_num, band_position,
						 offset)
	def get_dock(self):
		return GnomeDock(_obj=_gnomeui.gnome_app_get_dock(self._o))
	def get_dock_item_by_name(self, name):
		return GnomeDockItem(
			_obj=_gnomeui.gnome_app_get_dock_item_by_name(self._o,
								      name))
	def create_menus(self, menuinfo):
		_gnomeui.gnome_app_create_menus(self._o, menuinfo)
	def create_toolbar(self, toolbarinfo):
		_gnomeui.gnome_app_create_toolbar(self._o, toolbarinfo)
	def remove_menus(self, path, num):
		_gnomeui.gnome_app_remove_menus(self._o, path, num)
	def remove_menu_range(self, path, start, num):
		_gnomeui.gnome_app_remove_menu_range(self._o, path, start, num)
	def insert_menus(self, path, menuinfo):
		_gnomeui.gnome_app_insert_menus(self._o, path, menuinfo)
	def install_menu_hints(self, menuinfo):
		# to be called AFTER adding a statusbar
		_gnomeui.gnome_app_install_menu_hints(self._o, menuinfo)

	def message(self, message):
		_gnomeui.gnome_app_message(self._o, message)
	def flash(self, message):
		_gnomeui.gnome_app_flash(self._o, message)
	def error(self, error):
		_gnomeui.gnome_app_error(self._o, error)
	def warning(self, warning):
		_gnomeui.gnome_app_warning(self._o, warning)
	def question(self, question, callback):
		_gnomeui.gnome_app_question(self._o, question, callback)
	def ok_cancel(self, question, callback):
		_gnomeui.gnome_app_ok_cancel(self._o, question, callback)
	def request_string(self, prompt, callback):
		_gnomeui.gnome_app_request_string(self._o, prompt, callback)
	def request_password(self, prompt, callback):
		_gnomeui.gnome_app_request_password(self._o, prompt, callback)
_gtk._name2cls['GnomeApp'] = GnomeApp

class GnomeAppBar(_gtk.GtkHBox):
	get_type = _gnomeui.gnome_appbar_get_type
	def __init__(self, has_progress=1, has_status=1,
		     interactivity=PREFERENCES_USER, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_appbar_new(has_progress, has_status,
						    interactivity)
	def interactive(self):
		return _gnomeui.GNOME_APPBAR_INTERACTIVE(self._o)
	def set_status(self, status):
		_gnomeui.gnome_appbar_set_status(self._o, status)
	def set_default(self, default_status):
		_gnomeui.gnome_appbar_set_default(self._o, default_status)
	def push(self, status):
		_gnomeui.gnome_appbar_push(self._o, status)
	def pop(self):
		_gnomeui.gnome_appbar_pop(self._o)
	def clear_stack(self):
		_gnomeui.gnome_appbar_clear_stack(self._o)
	def set_progress(self, percentage):
		_gnomeui.gnome_appbar_set_progress(self._o, percentage)
	def get_progress(self):
		return _obj2inst(_gnomeui.gnome_appbar_get_progress(self._o))
	def refresh(self):
		_gnomeui.gnome_appbar_refresh(self._o)
	def set_prompt(self, prompt, modal=_gtk.FALSE):
		_gnomeui.gnome_appbar_set_prompt(self._o, prompt, modal)
	def clear_prompt(self):
		_gnomeui.gnome_appbar_clear_prompt(self._o)
	def get_response(self):
		return _gnomeui.gnome_appbar_get_response(self._o)
_gtk._name2cls['GnomeAppBar'] = GnomeAppBar

class GnomeCalculator(_gtk.GtkVBox):
	get_type = _gnomeui.gnome_calculator_get_type
	def __init__(self, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_calculator_new()
	def clear(self, reset=1):
		_gnomeui.gnome_calculator_clear(self._o, reset)
	def set(self, result):
		_gnomeui.gnome_calculator_set(self._o, result)
	def get_result(self):
		return _gnomeui.gnome_calculator_get_result(self._o)
_gtk._name2cls['GnomeCalculator'] = GnomeCalculator

class GnomeCanvas(_gtk.GtkLayout):
	get_type = _gnomeui.gnome_canvas_get_type
	def __init__(self, aa=_gtk.FALSE, _obj=None):
		if _obj: self._o = _obj; return
		if aa:
			self._o = _gnomeui.gnome_canvas_new_aa()
		else:
			self._o = _gnomeui.gnome_canvas_new()
	def root(self):
		return GnomeCanvasGroup(
			_obj=_gnomeui.gnome_canvas_root(self._o))
	def set_scroll_region(self, x1,y1, x2,y2):
		_gnomeui.gnome_canvas_set_scroll_region(self._o, x1,y1, x2,y2)
	def get_scroll_region(self):
		return _gnomeui.gnome_canvas_get_scroll_region(self._o)
	def set_pixels_per_unit(self, n):
		_gnomeui.gnome_canvas_set_pixels_per_unit(self._o, n)
	def set_size(self, width, height):
		print "GnomeCanvas.set_size deprecated -- use set_usize"
		self.set_usize(width, height)
	def scroll_to(self, cx, cy):
		_gnomeui.gnome_canvas_scroll_to(self._o, cx, cy)
	def get_scroll_offsets(self):
		return _gnomeui.gnome_canvas_get_scroll_offsets(self._o)
	def update_now(self):
		_gnomeui.gnome_canvas_update_now(self._o)
	def get_item_at(self, x, y):
		ret = _gnomeui.gnome_canvas_get_item_at(self._o, x, y)
		if (ret): return _obj2inst(ret)
		return None
	def request_redraw(self, x1,y1, x2,y2):
		_gnomeui.gnome_canvas_request_redraw(self._o, x1,y1, x2,y2)
	def w2c(self, wx, wy):
		return _gnomeui.gnome_canvas_w2c(self._o, wx, wy)
	def c2w(self, cx, cy):
		return _gnomeui.gnome_canvas_c2w(self._o, cx, cy)
	def get_color(self, spec):
		return _gnomeui.gnome_canvas_get_color(self._o, spec)
	def set_stipple_origin(self, gc):
		_gnomeui.gnome_canvas_set_stipple_origin(self._o, gc)
_gtk._name2cls['GnomeCanvas'] = GnomeCanvas

class GnomeCanvasItem(_gtk.GtkObject):
	get_type = _gnomeui.gnome_canvas_item_get_type
	def __init__(self, _obj=None):
		if _obj: self._o = _obj; return
	def set(self, **args):
		_filtprops(args)
		_gnomeui.gnome_canvas_item_set(self._o, args)
	def move(self, dx, dy):
		_gnomeui.gnome_canvas_item_move(self._o, dx, dy)
	def affine_relative(self, affine):
		_gnomeui.gnome_canvas_item_affine_relative(self._o, affine)
	def affine_absolute(self, affine):
		_gnomeui.gnome_canvas_item_affine_absolute(self._o, affine)
	def raise_(self, positions):
		_gnomeui.gnome_canvas_item_raise(self._o, positions)
	def lower(self, positions):
		_gnomeui.gnome_canvas_item_lower(self._o, positions)
	def raise_to_top(self):
		_gnomeui.gnome_canvas_item_raise_to_top(self._o)
	def lower_to_bottom(self):
		_gnomeui.gnome_canvas_item_lower_to_bottom(self._o)
	def show(self):
		_gnomeui.gnome_canvas_item_show(self._o)
	def hide(self):
		_gnomeui.gnome_canvas_item_hide(self._o)
	def grab(self, mask, cursor, event_time):
		_gnomeui.gnome_canvas_item_grab(self._o, mask,
						cursor, event_time)
	def ungrab(self, event_time):
		_gnomeui.gnome_canvas_item_ungrab(self._o, event_time)
	def reparent(self, new_group):
		_gnomeui.gnome_canvas_item_reparent(self._o, new_group._o)
	def grab_focus(self):
		_gnomeui.gnome_canvas_item_grab_focus(self._o)
	def get_bounds(self):
		return _gnomeui.gnome_canvas_item_get_bounds(self._o)
	def w2i(self, x, y):
		return _gnomeui.gnome_canvas_item_w2i(self._o, x, y)
	def i2w(self, x, y):
		return _gnomeui.gnome_canvas_item_i2w(self._o, x, y)
_gtk._name2cls['GnomeCanvasItem'] = GnomeCanvasItem

class GnomeCanvasGroup(GnomeCanvasItem):
	"""has arguments 'x' and 'y'.  eg you can go new_item('group', x=4)"""
	get_type = _gnomeui.gnome_canvas_group_get_type
	def add(self, tp, **args):
		types = {
			'item':     _gnomeui.gnome_canvas_item_get_type,
			'group':    _gnomeui.gnome_canvas_group_get_type,
			'icon_text':_gnomeui.gnome_icon_text_item_get_type,
			'image':    _gnomeui.gnome_canvas_image_get_type,
			'line':     _gnomeui.gnome_canvas_line_get_type,
			'polygon':  _gnomeui.gnome_canvas_polygon_get_type,
			're':       _gnomeui.gnome_canvas_re_get_type,
			'rect':     _gnomeui.gnome_canvas_rect_get_type,
			'ellipse':  _gnomeui.gnome_canvas_ellipse_get_type,
			'text':     _gnomeui.gnome_canvas_text_get_type,
			'widget':   _gnomeui.gnome_canvas_widget_get_type
		}
		if type(tp) == type('string'):
			tp = types[tp]()
		_filtprops(args)
		return _obj2inst(_gnomeui.gnome_canvas_item_new(self._o,
								tp, args))
	def new_item(self, tp, **args):
		print "I renamed this func to GnomeCanvasGroup.add"
		return apply(self.add, (tp,), args)
	def children(self):
		return map(_obj2inst, _gnomeui.gnome_canvas_group_children(
			self._o))
_gtk._name2cls['GnomeCanvasGroup'] = GnomeCanvasGroup

class GnomeCanvasImage(GnomeCanvasItem):
	"""has arguments 'image', 'x', 'y', 'width', 'height', 'anchor'"""
	get_type = _gnomeui.gnome_canvas_image_get_type
_gtk._name2cls['GnomeCanvasImage'] = GnomeCanvasItem

class GnomeCanvasLine(GnomeCanvasItem):
	"""has arguments 'points', 'fill_color', 'width_pixels',
	'width_units', 'cap_style', 'join_style', 'first_arrowhead',
	'last_arrowhead', 'smooth', 'spline_steps', 'arrow_shape_a',
	'arrow_shape_b', 'arrow_shape_c'"""
	get_type = _gnomeui.gnome_canvas_line_get_type
_gtk._name2cls['GnomeCanvasLine'] = GnomeCanvasLine

class GnomeCanvasPolygon(GnomeCanvasItem):
	"""has argyments 'points', 'fill_color', 'fill_color_gdk',
	'outlint_color', 'outline_color_gdk', 'fill_stipple',
	'outline_stipple', 'width_pixels', 'width_units'"""
	get_type = _gnomeui.gnome_canvas_polygon_get_type
_gtk._name2cls['GnomeCanvasPolygon'] = GnomeCanvasPolygon

class GnomeCanvasRE(GnomeCanvasItem):
	"""has arguments 'x1', 'y1', 'x2', 'y2', 'fill_color', 'outline_color',
	'width_pixels', 'width_units'"""
	get_type = _gnomeui.gnome_canvas_re_get_type
_gtk._name2cls['GnomeCanvasRE'] = GnomeCanvasRE

class GnomeCanvasRect(GnomeCanvasRE):
	"""has arguments of GnomeCanvasRE"""
	get_type = _gnomeui.gnome_canvas_rect_get_type
_gtk._name2cls['GnomeCanvasRect'] = GnomeCanvasRect

class GnomeCanvasEllipse(GnomeCanvasRE):
	"""has arguments of GnomeCanvasRE"""
	get_type = _gnomeui.gnome_canvas_ellipse_get_type
_gtk._name2cls['GnomeCanvasEllipse'] = GnomeCanvasEllipse

class GnomeCanvasText(GnomeCanvasItem):
	"""has arguments 'text', 'x', 'y', 'font', 'anchor', 'justification',
	'fill_color'"""
	get_type = _gnomeui.gnome_canvas_text_get_type
_gtk._name2cls['GnomeCanvasText'] = GnomeCanvasText

class GnomeCanvasWidget(GnomeCanvasItem):
	"""has arguments 'widget', 'x', 'y', 'width', 'height', 'anchor',
	'size_pixels'"""
	get_type = _gnomeui.gnome_canvas_widget_get_type
_gtk._name2cls['GnomeCanvasWidget'] = GnomeCanvasWidget

class GnomeClient(_gtk.GtkObject):
	get_type = _gnomeui.gnome_client_get_type
	def __init__(self, connected=_gtk.TRUE, _obj=None):
		if _obj: self._o = _obj; return
		if connected:
		    self._o = _gnomeui.gnome_client_new()
		else:
		    self._o = _gnomeui.gnome_client_new_without_connection()
	def connect(self):
		_gnomeui.gnome_client_connect(self._o)
	def disconnect(self):
		_gnomeui.gnome_client_disconnect(self._o)
	def set_id(self, client_id):
		_gnomeui.gnome_client_set_id(self._o, client_id)
	def get_id(self):
		return _gnomeui.gnome_client_get_id(self._o)
	def get_previous_id(self):
		return _gnomeui.gnome_client_get_previous_id(self._o)
	def get_config_prefix(self):
		return _gnomeui.gnome_client_get_config_prefix(self._o)
	def get_global_config_prefix(self):
		return _gnomeui.gnome_client_get_global_config_prefix(self._o)
	def set_clone_command(self, vector):
		_gnomeui.gnome_client_set_clone_command(self._o, vector)
	def set_discard_command(self, vector):
		_gnomeui.gnome_client_set_discard_command(self._o, vector)
	def set_environment(self, name, value):
		_gnomeui.gnome_client_set_environment(self._o, name, value)
	def set_restart_command(self, vector):
		_gnomeui.gnome_client_set_restart_command(self._o, vector)
	def set_resign_command(self, vector):
		_gnomeui.gnome_client_set_resign_command(self._o, vector)
	def set_shutdown_command(self, vector):
		_gnomeui.gnome_client_set_shutdown_command(self._o, vector)
	def set_current_directory(self, dir):
		_gnomeui.gnome_client_set_current_directory(self._o, dir)
	def set_process_id(self, pid):
		_gnomeui.gnome_client_set_process_id(self._o, pid)
	def set_program(self, program):
		_gnomeui.gnome_client_set_program(self._o, program)
	def set_restart_style(self, style):
		_gnomeui.gnome_client_set_restart_style(self._o, style)
	def set_priority(self, priority):
		_gnomeui.gnome_client_set_priority(self._o, priority)
	def set_user_id(self, user_id):
		_gnomeui.gnome_client_set_user_id(self._o, user_id)
	def request_phase_2(self):
		_gnomeui.gnome_client_request_phase_2(self._o)
	def request_interaction(self, dialog, func):
		_gnomeui.gnome_client_request_interaction(self._o,dialog,func)
	def request_save(self, save_style, shutdown, interact_style, fast,
			 is_global):
		_gnomeui.gnome_client_request_save(self._o, save_style,
						   shutdown, interact_style,
						   fast, is_global)
	def flush(self):
		_gnomeui.gnome_client_flush(self._o)
	def get_client_flags(self):
		return _gnomeui.gnome_client_get_client_flags(self._o)
_gtk._name2cls['GnomeClient'] = GnomeClient

def interaction_key_return(key, cancel_shutdown):
	_gnomeui.gnome_interaction_key_return(key, cancel_shutdown)
# set up the default SM client
master_client = GnomeClient(_obj=_gnomeui.gnome_master_client())

class GnomeClonedClient(GnomeClient):
	def __init__(self):
		self._o = _gnomeui.gnome_cloned_client()

class GnomeColorPicker(_gtk.GtkButton):
	get_type = _gnomeui.gnome_color_picker_get_type
	def __init__(self, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_color_picker_new()
	def set_d(self, r, g, b, a):
		_gnomeui.gnome_color_picker_set_d(self._o, r, g, b, a)
	def get_d(self):
		return _gnomeui.gnome_color_picker_get_d(self._o)
	def set_i8(self, r, g, b, a):
		_gnomeui.gnome_color_picker_set_i8(self._o, r, g, b, a)
	def get_i8(self):
		return _gnomeui.gnome_color_picker_get_i8(self._o)
	def set_i16(self, r, g, b, a):
		_gnomeui.gnome_color_picker_set_i16(self._o, r, g, b, a)
	def get_i16(self):
		return _gnomeui.gnome_color_picker_get_i16(self._o)
	def set_dither(self, dither):
		_gnomeui.gnome_color_picker_set_dither(self._o, dither)
	def set_use_alpha(self, use_alpha):
		_gnomeui.gnome_color_picker_set_use_alpha(self._o, use_alpha)
	def set_title(self, title):
		_gnomeui.gnome_color_picker_set_title(self._o, title)
_gtk._name2cls['GnomeColorPicker'] = GnomeColorPicker

class GnomeDateEdit(_gtk.GtkHBox):
	get_type = _gnomeui.gnome_date_edit_get_type
	def __init__(self, the_time=0, flags=0, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_date_edit_new_flags(the_time, flags)
	def set_time(self, the_time):
		_gnomeui.gnome_date_edit_set_time(self._o, the_time)
	def set_popup_range(self, low_hour, up_hour):
		_gnomeui.gnome_date_edit_set_popup_range(self._o, low_hour,
							 up_hour)
	def get_date(self):
		return _gnomeui.gnome_date_edit_get_date(self._o)
	def set_flags(self, flags):
		_gnomeui.gnome_date_edit_set_flags(self._o, flags)
	def get_flags(self):
		return _gnomeui.gnome_date_edit_get_flags(self._o)
_gtk._name2cls['GnomeDateEdit'] = GnomeDateEdit

class GnomeDEntryEdit(_gtk.GtkObject):
	get_type = _gnomeui.gnome_dentry_edit_get_type
	def __init__(self, notebook=None, _obj=None):
		if _obj: self._o = _obj; return
		if notebook:
			self._o = _gnomeui.gnome_dentry_edit_new_notebook(
				notebook._o)
		else:
			self._o = _gnomeui.gnome_dentry_edit_new()
	def child1(self):
		return _obj2inst(_gnomeui.gnome_dentry_edit_child1(self._o))
	def child2(self):
		return _obj2inst(_gnomeui.gnome_dentry_edit_child2(self._o))
	def clear(self):
		_gnomeui.gnome_dentry_edit_clear(self._o)
	def load_file(self, filename):
		_gnomeui.gnome_dentry_edit_load_file(self._o, filename)
	# this is provided, because I haven't added dentry support to the
	# _gnome low-level module.
	def save_file(self, filename):
		_gnomeui.gnome_dentry_edit_save_file(self._o, filename)
	def get_icon(self):
		return _gnomeui.gnome_dentry_edit_get_icon(self._o)
	def get_name(self):
		return _gnomeui.gnome_dentry_edit_get_name(self._o)
	def get_name_entry(self):
		return _obj2inst(_gnomeui.gnome_dentry_edit_get_name_entry(
			self._o))
	def get_comment_entry(self):
		return _obj2inst(_gnomeui.gnome_dentry_edit_get_comment_entry(
			self._o))
	def get_exec_entry(self):
		return _obj2inst(_gnomeui.gnome_dentry_edit_get_exec_entry(
			self._o))
	def get_tryexec_entry(self):
		return _obj2inst(_gnomeui.gnome_dentry_edit_get_tryexec_entry(
			self._o))
	def get_doc_entry(self):
		return _obj2inst(_gnomeui.gnome_dentry_edit_get_doc_entry(
			self._o))
	def get_icon_entry(self):
		return _obj2inst(_gnomeui.gnome_dentry_edit_get_icon_entry(
			self._o))
_gtk._name2cls['GnomeDEntryEdit'] = GnomeDEntryEdit

class GnomeDockBand(_gtk.GtkContainer):
	get_type = _gnomeui.gnome_dock_band_get_type
	def __init__(self, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_dock_band_new()
	def set_orientation(self, orient):
		_gnomeui.gnome_dock_band_set_orientation(self._o, orient)
	def get_orientation(self):
		return _gnomeui.gnome_dock_band_get_orientation(self._o)
	def insert(self, child, offset, position):
		return _gnomeui.gnome_dock_band_insert(self._o, child._o,
						       offset, position)
	def prepend(self, child, offset):
		return _gnomeui.gnome_dock_band_prepend(self._o, child._o,
							offset)
	def append(self, child, offset):
		return _gnomeui.gnome_dock_band_append(self._o, child._o,
						       offset)
	def set_child_offset(self, child, offset):
		_gnomeui.gnome_dock_band_set_child_offset(self._o, child._o,
							  offset)
	def get_child_offset(self, child):
		return _gnomeui.gnome_dock_band_get_child_offset(self._o,
								 child._o)
	def get_num_children(self):
		return _gnomeui.gnome_dock_band_get_num_children(self._o)
	def drag_begin(self, item):
		_gnomeui.gnome_dock_band_drag_begin(self._o, item._o)
	def drag_to(self, item, x, y):
		_gnomeui.gnome_dock_band_drag_to(self._o, item._o, x, y)
	def drag_end(self, item):
		_gnomeui.gnome_dock_band_drag_end(self._o, item._o)
_gtk._name2cls['GnomeDockBand'] = GnomeDockBand

class GnomeDockItem(_gtk.GtkBin):
	get_type = _gnomeui.gnome_dock_item_get_type
	def __init__(self, name="", behaviour=DOCK_ITEM_BEH_NORMAL, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_dock_item_new(name, behaviour)
	def get_child(self):
		return _obj2inst(_gnomeui.gnome_dock_item_get_child(self._o))
	def get_name(self):
		return _gnomeui.gnome_dock_item_get_name(self._o)
	def set_shadow_type(self, type):
		_gnomeui.gnome_dock_item_set_shadow_type(self._o, type)
	def get_shadow_type(self):
		return _gnomeui.gnome_dock_item_get_shadow_type(self._o)
	def set_orientation(self, orient):
		_gnomeui.gnome_dock_item_set_orientation(self._o, orient)
	def get_orientation(self):
		return _gnomeui.gnome_dock_item_get_orientation(self._o)
	def get_behavior(self):
		return _gnomeui.gnome_dock_item_get_behavior(self._o)
_gtk._name2cls['GnomeDockItem'] = GnomeDockItem

class GnomeDock(_gtk.GtkContainer):
	get_type = _gnomeui.gnome_dock_get_type
	def __init__(self, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_dock_new()
	def allow_floating_items(self, enable):
		_gnomeui.gnome_dock_allow_floating_items(self._o, enable)
	def add_item(self, item, placement, band_num, position, offset,
		     in_new_band):
		_gnomeui.gnome_dock_add_item(self._o, item._o, placement,
					     band_num, position, offset,
					     in_new_band)
	def add_floating_item(self, item, x, y, orientation):
		_gnomeui.gnome_dock_add_item(self._o, item._o, x,y,orientation)
	def set_client_area(self, widget):
		_gnomeui.gnome_dock_set_client_area(self._o, widget._o)
	def get_client_area(self):
		return _obj2inst(_gnomeui.gnome_dock_get_client_area(self._o))
_gtk._name2cls['GnomeDock'] = GnomeDock

class GnomeDruid(_gtk.GtkContainer):
	get_type = _gnomeui.gnome_druid_get_type
	def __init__(self, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_druid_new()
	def set_buttons_sensitive(self, back_sens, next_sens, cancel_sens):
		_gnomeui.gnome_druid_set_buttons_sensitive(self._o, back_sens,
							   next_sens,
							   cancel_sens)
	def set_show_finish(self, show_finish):
		_gnomeui.gnome_druid_set_show_finish(self._o, show_finish)
	def prepend_page(self, page):
		_gnomeui.gnome_druid_prepend_page(self._o, page._o)
	def insert_page(self, back_page, page):
		_gnomeui.gnome_druid_insert_page(self._o, back_page._o,page._o)
	def append_page(self, page):
		_gnomeui.gnome_druid_append_page(self._o, page._o)
	def set_page(self, page):
		_gnomeui.gnome_druid_set_page(self._o, page._o)
_gtk._name2cls['GnomeDruid'] = GnomeDruid

class GnomeDruidPage(_gtk.GtkBin):
	get_type = _gnomeui.gnome_druid_page_get_type
	def next(self):
		return _gnomeui.gnome_druid_page_next(self._o)
	def prepare(self):
		_gnomeui.gnome_druid_page_prepare(self._o)
	def back(self):
		return _gnomeui.gnome_druid_page_back(self._o)
	def cancel(self):
		return _gnomeui.gnome_druid_page_cancel(self._o)
	def finish(self):
		_gnomeui.gnome_druid_page_finish(self._o)
_gtk._name2cls['GnomeDruidPage'] = GnomeDruidPage

class GnomeDruidPageStart(GnomeDruidPage):
	get_type = _gnomeui.gnome_druid_page_start_get_type
	def __init__(self, title=None, text=None, logo=None, watermark=None,
		     _obj=None):
		if _obj: self._o = _obj; return
		if logo: logo = logo._im
		if watermark: watermark = watermark._im
		self._o = _gnomeui.gnome_druid_page_start_new_with_vals(
			title, text, logo, watermark)
	def set_bg_color(self, colour):
		_gnomeui.gnome_druid_page_start_set_bg_color(self._o, colour)
	def set_textbox_color(self, colour):
		_gnomeui.gnome_druid_page_start_set_textbox_color(self._o,
								  colour)
	def set_logo_bg_color(self, colour):
		_gnomeui.gnome_druid_page_start_set_logo_bg_color(self._o,
								  colour)
	def set_title_color(self, colour):
		_gnomeui.gnome_druid_page_start_set_title_color(self._o,colour)
	def set_text_color(self, colour):
		_gnomeui.gnome_druid_page_start_set_text_color(self._o, colour)
	def set_text(self, text):
		_gnomeui.gnome_druid_page_start_set_text(self._o, text)
	def set_title(self, title):
		_gnomeui.gnome_druid_page_start_set_title(self._o, title)
	def set_logo(self, image):
		_gnomeui.gnome_druid_page_start_set_logo(self._o, image._im)
	def set_watermark(self, image):
		_gnomeui.gnome_druid_page_start_set_watermark(self._o,
							      image._im)
_gtk._name2cls['GnomeDruidPageStart'] = GnomeDruidPageStart

class GnomeDruidPageFinish(GnomeDruidPage):
	get_type = _gnomeui.gnome_druid_page_finish_get_type
	def __init__(self, title=None, text=None, logo=None, watermark=None,
		     _obj=None):
		if _obj: self._o = _obj; return
		if logo: logo = logo._im
		if watermark: watermark = watermark._im
		self._o = _gnomeui.gnome_druid_page_finish_new_with_vals(
			title, text, logo, watermark)
	def set_bg_color(self, colour):
		_gnomeui.gnome_druid_page_finish_set_bg_color(self._o, colour)
	def set_textbox_color(self, colour):
		_gnomeui.gnome_druid_page_finish_set_textbox_color(self._o,
								   colour)
	def set_logo_bg_color(self, colour):
		_gnomeui.gnome_druid_page_finish_set_logo_bg_color(self._o,
								   colour)
	def set_title_color(self, colour):
		_gnomeui.gnome_druid_page_finish_set_title_color(self._o,
								 colour)
	def set_text_color(self, colour):
		_gnomeui.gnome_druid_page_finish_set_text_color(self._o,colour)
	def set_text(self, text):
		_gnomeui.gnome_druid_page_finish_set_text(self._o, text)
	def set_title(self, title):
		_gnomeui.gnome_druid_page_finish_set_title(self._o, title)
	def set_logo(self, image):
		_gnomeui.gnome_druid_page_finish_set_logo(self._o, image._im)
	def set_watermark(self, image):
		_gnomeui.gnome_druid_page_finish_set_watermark(self._o,
							       image._im)
_gtk._name2cls['GnomeDruidPageFinish'] = GnomeDruidPageFinish

class GnomeDruidPageStandard(GnomeDruidPage):
	get_type = _gnomeui.gnome_druid_page_standard_get_type
	def __init__(self, title=None, logo=None, _obj=None):
		if _obj: self._o = _obj; return
		if logo: logo = logo._im
		self._o = _gnomeui.gnome_druid_page_standard_new_with_vals(
			title, logo)
	def __getattr__(self, attr):
		if attr == 'vbox':
			return _obj2inst(_gnomeui.gnome_druid_page_standard_get_vbox(
				self._o))
		else:
			return GnomeDruidPage.__getattr(self, attr)
	def set_bg_color(self, color):
		_gnomeui.gnome_druid_page_standard_set_bg_color(self._o, color)
	def set_logo_bg_color(self, color):
		_gnomeui.gnome_druid_page_standard_set_logo_bg_color(self._o,
								     color)
	def set_title_color(self, color):
		_gnomeui.gnome_druid_page_standard_set_title_color(self._o,
								   color)
	def set_title(self, title):
		_gnomeui.gnome_druid_page_set_title(self._o, title)
	def set_logo(self, image):
		_gnomeui.gnome_druid_page_set_logo(self._o, image._im)
_gtk._name2cls['GnomeDruidPageStandard'] = GnomeDruidPageStandard

class GnomeEntry(_gtk.GtkCombo):
	get_type = _gnomeui.gnome_entry_get_type
	def __init__(self, history_id='', _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_entry_new(history_id)
	def gtk_entry(self):
		return _obj2inst(_gnomeui.gnome_entry_gtk_entry(self._o))
	def set_history_id(self, history_id):
		_gnomeui.gnome_entry_set_history_id(self._o, history_id)
	def prepend_history(self, save, text):
		_gnomeui.gnome_entry_prepend_history(self._o, save, text)
	def append_history(self, save, text):
		_gnomeui.gnome_entry_append_history(self._o, save, text)
	def load_history(self):
		_gnomeui.gnome_entry_load_history(self._o)
	def save_history(self):
		_gnomeui.gnome_entry_save_history(self._o)
_gtk._name2cls['GnomeEntry'] = GnomeEntry

class GnomeFileEntry(_gtk.GtkHBox):
	get_type = _gnomeui.gnome_file_entry_get_type
	def __init__(self, history_id='', browse_dialog_title='', _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_file_entry_new(history_id,
							browse_dialog_title)
	def gnome_entry(self):
		return _obj2inst(_gnomeui.gnome_file_entry_gnome_entry(
			self._o))
	def gtk_entry(self):
		return _obj2inst(_gnomeui.gnome_file_entry_gtk_entry(self._o))
	def set_title(self, browse_dialog_title):
		_gnomeui.gnome_file_entry_set_title(self._o,
						    browse_dialog_title)
	def set_default_path(self, path):
		_gnomeui.gnome_file_entry_set_default_path(self._o, path)
	def get_full_path(self, file_must_exist):
		return _gnomeui.gnome_file_entry_get_full_path(self._o,
							       file_must_exist)
	def set_modal(self, is_modal=_gtk.TRUE):
		_gnomeui.gnome_file_entry_set_modal(self._o, is_modal)
_gtk._name2cls['GnomeFileEntry'] = GnomeFileEntry

class GnomeFontPicker(_gtk.GtkButton):
	get_type = _gnomeui.gnome_font_picker_get_type
	def __init__(self, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_font_picker_new()
	def set_title(self, title):
		_gnomeui.gnome_font_picker_set_title(self._o, title)
	def get_mode(self):
		return _gnomeui.gnome_font_picker_get_mode(self._o)
	def set_mode(self, mode):
		_gnomeui.gnome_font_picker_set_mode(self._o, mode)
	def fi_set_use_font_in_label(self, use_font_in_label, size):
		_gnomeui.gnome_font_picker_fi_set_use_font_in_label(
			self._o, use_font_in_label, size)
	def fi_set_show_size(self, show_size):
		_gnomeui.gnome_font_picker_fi_set_show_size(self._o, show_size)
	def uw_set_widget(self, widget):
		_gnomeui.gnome_font_picker_uw_set_widget(self._o, widget._o)
	def get_font_name(self):
		return _gnomeui.gnome_font_picker_get_font_name(self._o)
	def get_font(self):
		return _gnomeui.gnoem_font_picker_get_font(self._o)
	def set_font_name(self, fontname):
		_gnomeui.gnome_font_picker_set_font_name(self._o, fontname)
	def get_preview_text(self):
		return _gnomeui.gnome_font_picker_get_preview_text(self._o)
	def set_preview_text(self, text):
		_gnomeui.gnome_font_picker_set_preview_text(self._o, text)
_gtk._name2cls['GnomeFontPicker'] = GnomeFontPicker

class GnomeGuru(_gtk.GtkVBox):
	get_type = _gnomeui.gnome_guru_get_type
	def __init__(self, name=None, graphic=None, dialog=None, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_guru_new(name, graphic._o, dialog._o)
	def append_page(self, name, page):
		_gnomeui.gnome_guru_append_page(self._o, name, page._o)
	def next_set_sensitive(self, sensitivity):
		_gnomeui.gnome_guru_next_set_sensitivity(self._o, sensitivity)
	def back_set_sensitive(self, sensitivity):
		_gnomeui.gnome_guru_back_set_sensitivity(self._o, sensitivity)
	def current_page(self):
		return _gnomeui.gnome_guru_current_page(self._o)
_gtk._name2cls['GnomeGuru'] = GnomeGuru

class GnomeHRef(_gtk.GtkButton):
	get_type = _gnomeui.gnome_href_get_type
	def __init__(self, url='', label=None, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_href_new(url, label)
	def set_url(self, url):
		_gnomeui.gnome_href_set_url(self._o, url)
	def get_url(self):
		return _gnomeui.gnome_href_get_url(self._o)
	def set_label(self, label):
		_gnomeui.gnome_href_set_label(self._o, label)
	def get_label(self):
		return _gnomeui.gnome_href_get_label(self._o)
_gtk._name2cls['GnomeHRef'] = GnomeHRef

class GnomeIconEntry(_gtk.GtkVBox):
	get_type = _gnomeui.gnome_icon_entry_get_type
	def __init__(self, history_id='', browse_dialog_title='', _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_icon_entry_new(history_id,
							browse_dialog_title)
	def set_pixmap_subdir(self, subdir):
		_gnomeui.gnome_icon_entry_set_pixmap_subdir(self._o, subdir)
	def set_icon(self, filename):
		_gnomeui.gnome_icon_entry_set_icon(self._o, filename)
	def gnome_file_entry(self):
		return GnomeFileEntry(_obj=
			_gnomeui.gnome_icon_entry_gnome_file_entry(self._o))
	def gnome_entry(self):
		return GnomeEntry(_obj=
			_gnomeui.gnome_icon_entry_gnome_entry(self._o))
	def gtk_entry(self):
		return _gtk.GtkEntry(_obj=
			_gnomeui.gnome_icon_entry_gtk_entry(self._o))
	def get_filename(self):
		return _gnomeui.gnome_icon_entry_get_filename(self._o)
_gtk._name2cls['GnomeIconEntry'] = GnomeIconEntry

class GnomeIconList(GnomeCanvas):
	get_type = _gnomeui.gnome_icon_list_get_type
	def __init__(self, icon_width=70, adj=None,
		     is_editable=_gtk.FALSE, _obj=None):
		if _obj: self._o = _obj; return
		if adj: adj = adj._o
		self._o = _gnomeui.gnome_icon_list_new(icon_width, adj,
						       is_editable)
	def set_selection_mode(self, mode):
		_gnomeui.gnome_icon_list_set_selection_mode(self._o, mode)
	def append(self, icon_filename, text):
		return _gnomeui.gnome_icon_list_append(self._o, icon_filename,
						       text)
	def append_imlib(self, image, text):
		return _gnomeui.gnome_icon_list_append_imlib(self._o,
							     image._im, text)
	def insert(self, pos, icon_filename, text):
		_gnomeui.gnome_icon_list_insert(self._o, pos, icon_filename,
						text)
	def insert_imlib(self, pos, image, text):
		_gnomeui.gnome_icon_list_insert_imlib(self._o, pos, image._im,
						      text)
	def clear(self):
		_gnomeui.gnome_icon_list_clear(self._o)
	def remove(self, pos):
		_gnomeui.gnome_icon_list_remove(self._o, pos)
	def set_icon_data(self, pos, data):
		_gnomeui.gnome_icon_list_set_icon_data(self._o, pos, data)
	def get_icon_data(self, pos):
		return _gnomeui.gnome_icon_list_get_icon_data(self._o, pos)
	def find_icon_from_data(self, data):
		return _gnomeui.gnome_icon_list_find_icon_from_data(self._o,
								    data)
	def select_icon(self, pos):
		_gnomeui.gnome_icon_list_select_icon(self._o, pos)
	def unselect_icon(self, pos):
		_gnomeui.gnome_icon_list_unselect_icon(self._o, pos)
	def select_all(self, event):
		_gnomeui.gnome_icon_list_select_all(self._o, event)
	def freeze(self):
		_gnomeui.gnome_icon_list_freeze(self._o)
	def thaw(self):
		_gnomeui.gnome_icon_list_thaw(self._o)
	def moveto(self, pos, yalign=0.5):
		_gnomeui.gnome_icon_list_moveto(self._o, pos, yalign)
	def icon_is_visible(self, pos):
		return _gnomeui.gnome_icon_list_icon_is_visible(self._o, pos)
	def set_icon_width(self, width):
		_gnomeui.gnome_icon_list_set_icon_width(self._o, width)
	def set_row_spacing(self, spacing):
		_gnomeui.gnome_icon_list_set_row_spacing(self._o, spacing)
	def set_col_spacing(self, spacing):
		_gnomeui.gnome_icon_list_set_col_spacing(self._o, spacing)
	def set_text_spacing(self, spacing):
		_gnomeui.gnome_icon_list_set_text_spacing(self._o, spacing)
	def set_icon_border(self, spacing):
		_gnomeui.gnome_icon_list_set_icon_border(self._o, spacing)
	def set_separators(self, separators):
		_gnomeui.gnome_icon_list_set_separators(self._o, separators)
	def set_hadjustment(self, adj):
		_gnomeui.gnome_icon_list_set_hadjustment(self._o, adj._o)
	def set_vadjustment(self, adj):
		_gnomeui.gnome_icon_list_set_vadjustment(self._o, adj._o)
	def get_icon_at(self, x, y):
		return _gnomeui.gnome_icon_list_get_icon_at(self._o, x, y)
	def get_items_per_line(self):
		return _gnomeui.gnome_icon_list_get_items_per_line(self._o)
_gtk._name2cls['GnomeIconList'] = GnomeIconList

class GnomeIconTextItem(GnomeCanvasItem):
	get_type = _gnomeui.gnome_icon_text_item_get_type
	def setxy(self, x, y):
		_gnomeui.gnome_icon_text_item_setxy(self._o, x, y)
	def select(self, select):
		_gnomeui.gnome_icon_text_item_select(self._o, select)
	def get_text(self):
		return _gnomeui.gnome_icon_text_item_get_text(self._o)
	def stop_editing(self):
		_gnomeui.gnome_icon_text_stop_editing(self._o)

class GnomeIconSelection(_gtk.GtkVBox):
	get_type = _gnomeui.gnome_icon_selection_get_type
	def __init__(self, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_icon_selection_new()
	def add_defaults(self):
		_gnomeui.gnome_icon_selection_add_defaults(self._o)
	def add_directory(self, dir):
		_gnomeui.gnome_icon_selection_add_directory(self._o, dir)
	def show_icons(self):
		_gnomeui.gnome_icon_selection_show_icons(self._o)
	def clear(self, not_shown=_gtk.TRUE):
		_gnomeui.gnome_icon_selection_clear(self._o, not_shown)
	def get_icon(self, full_path=_gtk.TRUE):
		return _gnomeui.gnome_icon_selection_get_icon(self._o,
							      full_path)
	def select_icon(self, filename):
		_gnomeui.gnome_icon_selection_select_icon(self._o, filename)
_gtk._name2cls['GnomeIconSelection'] = GnomeIconSelection

class GnomeLess(_gtk.GtkVBox):
	get_type = _gnomeui.gnome_less_get_type
	def __init__(self, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_less_new()
	def clear(self):
		_gnomeui.gnome_less_clear(self._o)
	def show_file(self, path):
		return _gnomeui.gnome_less_show_file(self._o, path)
	def show_command(self, command_line):
		return _gnomeui.gnome_less_show_command(self._o, command_line)
	def show_string(self, string):
		_gnomeui.gnome_less_show_string(self._o, string)
	def show_filestream(self, fp):
		return _gnomeui.gnome_less_show_filestream(self._o, fp)
	def write_file(self, filename):
		return _gnomeui.gnome_less_write_file(self._o, filename)
	def set_font(self, font):
		_gnomeui.gnome_less_set_font(self._o, font)
	def set_fixed_font(self, fixed):
		_gnomeui.gnome_less_set_fixed_font(self._o, fixed)
	def reshow(self):
		_gnomeui.gnome_less_reshow(self._o)
_gtk._name2cls['GnomeLess'] = GnomeLess

class GnomeMDI(_gtk.GtkObject):
	get_type = _gnomeui.gnome_mdi_get_type
	def __init__(self, appname=None, title=None, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_mdi_new(appname, title)
	def set_mode(self, mode):
		_gnomeui.gnome_mdi_set_mode(self._o, mode)
	def set_menubar_template(self, info):
		_gnomeui.gnome_mdi_set_menubar_template(self._o, info)
	def set_toolbar_template(self, info):
		_gnomeui.gnome_mdi_set_toolbar_template(self._o, info)
	def set_child_menu_path(self, path):
		_gnomeui.gnome_mdi_set_child_menu_path(self._o, path)
	def set_child_list_path(self, path):
		_gnomeui.gnome_mdi_set_child_list_path(self._o, path)
	def get_active_child(self):
		return GnomeMDIChild(
			_obj=_gnomeui.gnome_mdi_get_active_child(self._o))
	def find_child(self, name):
		return GnomeMDIChild(
			_obj=_gnomeui.gnome_mdi_find_child(self._o, name))
	def add_view(self, child):
		return _gnomeui.gnome_mdi_add_view(self._o, child._o)
	def add_toplevel_view(self, child):
		return _gnomeui.gnome_mdi_add_view(self._o, child._o)
	def remove_view(self, wid, force):
		return _gnomeui.gnome_mdi_remove_view(self._o, wid._o, force)
	def get_active_view(self):
		return _obj2inst(_gnomeui.gnome_mdi_get_active_view(self._o))
	def add_child(self, child):
		return _gnomeui.gnome_mdi_add_child(self._o, child._o)
	def remove_child(self, child, force):
		return _gnomeui.gnome_mdi_remove_child(self._o, child._o,force)
	def remove_all(self, force):
		return _gnomeui.gnome_mdi_remove_all(self._o, force)
	def open_toplevel(self):
		_gnomeui.gnome_mdi_open_toplevel(self._o)
	def update_child(self, child):
		_gnomeui.gnome_mdi_update_child(self._o, child._o)
	def get_active_window(self):
		return GnomeApp(_obj=
				_gnomeui.gnome_mdi_get_active_window(self._o))
	def register(self, wid):
		_gnomeui.gnome_mdi_register(self._o, wid._o)
	def unregister(self, wid):
		_gnomeui.gnome_mdi_unregister(self._o, wid._o)
	def get_app_from_view(self, view):
		return GnomeApp(_obj=
				_gnomeui.gnome_mdi_get_app_from_view(view._o))
	def get_child_from_view(self, view):
		return GnomeMDIChild(_obj=
				     _gnomeui.gnome_mdi_get_child_from_view(
					     view._o))
	def get_view_from_window(self, app):
		return _obj2inst(_gnomeui.gnome_mdi_get_view_from_window(
			self._o, app._o))
	def set_active_view(self, view):
		_gnomeui.gnome_mdi_set_active_view(self._o, view._o)
_gtk._name2cls['GnomeMDI'] = GnomeMDI

class GnomeMDIChild(_gtk.GtkObject):
	get_type = _gnomeui.gnome_mdi_child_get_type
	def __init__(self, _obj=None):
		if _obj: self._o = _obj; return
		raise RuntimeError, \
		      "can only initialise GnomeMDIChild subclasses"
	def add_view(self):
		return _obj2inst(_gnomeui.gnome_mdi_child_add_view(self._o))
	def remove_view(self, view):
		_gnomeui.gnome_mdi_child_remove_view(self._o, view._o)
	def set_name(self, name):
		_gnomeui.gnome_mdi_child_set_name(self._o, name)
	def set_menu_template(self, info):
		_gnomeui.gnome_mdi_child_set_menu_template(self._o, info)
_gtk._name2cls['GnomeMDIChild'] = GnomeMDIChild

class GnomeMDIGenericChild(GnomeMDIChild):
	get_type = _gnomeui.gnome_mdi_generic_child_get_type
	def __init__(self, name="", _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_mdi_generic_child_new(name)
	class __marshal:
		def __init__(self, func):
			self.func = func
		def __call__(self, *args):
			a = list(args)
			for i in range(len(args)):
				if type(args[i]) == _gtk._gtk.GtkObjectType:
					a[i] = _obj2inst(args[i])
			a = tuple(a)
			ret = apply(self.func, a)
			if hasattr(ret, '_o'): ret = ret._o
			return ret
	def set_view_creator(self, func, *args):
		mfunc = self.__marshal(func).__call__
		_gnomeui.gnome_mdi_generic_child_set_view_creator(self._o, mfunc,
								  args)
	def set_menu_creator(self, func, *args):
		mfunc = self.__marshal(func).__call__
		_gnomeui.gnome_mdi_generic_child_set_menu_creator(self._o, mfunc,
								  args)
	def set_config_func(self, func, *args):
		mfunc = self.__marshal(func).__call__
		_gnomeui.gnome_mdi_generic_child_set_config_func(self._o, mfunc,
								 args)
	def set_label_func(self, func, *args):
		mfunc = self.__marshal(func).__call__
		_gnomeui.gnome_mdi_generic_child_set_label_func(self._o, mfunc,
								args)
_gtk._name2cls['GnomeMDIGenericChild'] = GnomeMDIGenericChild

class GnomeMessageBox(GnomeDialog):
	get_type = _gnomeui.gnome_message_box_get_type
	def __init__(self, message='', messagebox_type='', b1=None, b2=None,
		     b3=None, b4=None, b5=None, b6=None, b7=None, b8=None,
		     b9=None, b10=None, _obj=None):
		if _obj: self._o = _obj; return
		buttons = filter(lambda x: x, (b1,b2,b3,b4,b5,b6,b7,b8,b9,b10))
		self._o = apply(_gnomeui.gnome_message_box_new,
				(message, messagebox_type) + buttons)
_gtk._name2cls['GnomeMessageBox'] = GnomeMessageBox

class GnomeNumberEntry(_gtk.GtkHBox):
	get_type = _gnomeui.gnome_number_entry_get_type
	def __init__(self, history_id=None, dlg_title=None, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_number_entry_new(history_id,
							  dlg_title)
	def gnome_entry(self):
		return GnomeEntry(
			_obj=_gnomeui.gnome_number_entry_gnome_entry(self._o))
	def gtk_entry(self):
		return _gtk.GtkEntry(
			_obj=_gnomeui.gnome_number_entry_gtk_entry(self._o))
	def set_title(self, dlg_title):
		_gnomeui.gnome_number_entry_set_title(self._o, dlg_title)
	def get_number(self):
		return _gnomeui.gnome_number_entry_get_number(self._o)
_gtk._name2cls['GnomeNumberEntry'] = GnomeNumberEntry

class GnomePaperSelector(_gtk.GtkVBox):
	get_type = _gnomeui.gnome_paper_selector_get_type
	def __init__(self, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_paper_selector_new()
	def get_name(self):
		return _gnomeui.gnome_paper_selector_get_name(self._o)
	def get_width(self):
		return _gnomeui.gnome_paper_selector_get_width(self._o)
	def get_height(self):
		return _gnomeui.gnome_paper_selector_get_height(self._o)
	def get_left_margin(self):
		return _gnomeui.gnome_paper_selector_get_left_margin(self._o)
	def get_right_margin(self):
		return _gnomeui.gnome_paper_selector_get_right_margin(self._o)
	def get_top_margin(self):
		return _gnomeui.gnome_paper_selector_get_top_margin(self._o)
	def get_bottom_margin(self):
		return _gnomeui.gnome_paper_selector_get_bottom_margin(self._o)
_gtk._name2cls['GnomePaperSelector'] = GnomePaperSelector

class GnomePixmap(_gtk.GtkWidget):
	get_type = _gnomeui.gnome_pixmap_get_type
	def __init__(self, filename='', width=-1, height=-1, _obj=None):
		if _obj: self._o = _obj; return
		if (width, height) == (-1, -1):
			if hasattr(filename, '_im'):
				self._o = _gnomeui.gnome_pixmap_new_from_imlib(
					filename._im)
			else:
				self._o = _gnomeui.gnome_pixmap_new_from_file(
					filename)
		else:
			if hasattr(filename, '_im'):
				self._o = _gnomeui.gnome_pixmap_new_from_imlib_at_size(
					filename._im, width, height)
			else:
				self._o = _gnomeui.gnome_pixmap_new_from_file_at_size(
					filename, width, height)
	def load_file(self, filename, width=-1, height=-1):
		if (width, height) == (-1, -1):
			_gnomeui.gnome_pixmap_load_file(self._o, filename)
		else:
			_gnomeui.gnome_pixmap_load_file_at_size(self._o,
						filename, width, height)
	def load_imlib(self, image, width=-1, height=-1):
		if (width, height) == (-1, -1):
			_gnomeui.gnome_pixmap_load_imlib(self._o, image._im)
		else:
			_gnomeui.gnome_pixmap_load_imlib_at_size(self._o,
						image._im, width, height)
_gtk._name2cls['GnomePixmap'] = GnomePixmap

class GnomePixmapEntry(_gtk.GtkVBox):
	get_type = _gnomeui.gnome_pixmap_entry_get_type
	def __init__(self, history_id='', browse_dialog_title='',
		     do_preview=_gtk.TRUE, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_pixmap_entry_new(history_id,
							  browse_dialog_title,
							  do_preview)
	def set_pixmap_subdir(self, subdir):
		_gnomeui.gnome_pixmap_entry_set_pixmap_subdir(self._o, subdir)
	def gnome_file_entry(self):
		return GnomeFileEntry(_obj=
			_gnomeui.gnome_pixmap_entry_gnome_file_entry(self._o))
	def gnome_entry(self):
		return GnomeEntry(_obj=
			_gnomeui.gnome_pixmap_entry_gnome_entry(self._o))
	def gtk_entry(self):
		return _gtk.GtkEntry(_obj=
			_gnomeui.gnome_pixmap_entry_gtk_entry(self._o))
	def set_preview(self, do_preview):
		_gnomeui.gnome_pixmap_entry_set_preview(self._o, do_preview)
	def set_preview_size(self, width, height):
		_gnomeui.gnome_pixmap_entry_set_preview_size(self._o, width,
							     height)
	def get_filename(self):
		return _gnomeui.gnome_pixmap_entry_get_filename(self._o)
_gtk._name2cls['GnomePixmapEntry'] = GnomePixmapEntry

# The popup help stuff
def add_help(self, string, uidata=None):
	if uidata:
		_gnomeui.gnome_widget_add_help_with_uidata(self._o, string,
							   uidata)
	else:
		_gnomeui.gnome_widget_add_help(self._o, string)
_gtk.GtkWidget.__dict__['add_help'] = add_help
del add_help

# I think this will work now (hopefully)
class GnomePopupMenu(_gtk.GtkMenu):
	def __init__(self, uiinfo):
		self._o = _gnomeui.gnome_popup_menu_new(uiinfo)
	def attach(self, child):
		_gnomeui.gnome_popup_menu_attach(self._o, child._o)

class GnomePropertyBox(GnomeDialog):
	get_type = _gnomeui.gnome_property_box_get_type
	def __init__(self, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_property_box_new()
	def changed(self, obj=None):
		_gnomeui.gnome_property_box_changed(self._o)
	def set_state(self, state):
		print "GnomePropertyBox.set_state deprecated -- use set_modified"
		self.set_modified(state)
	def set_modified(self, modified):
		_gnomeui.gnome_property_box_set_modified(self._o, modified)
	def append_page(self, child, tab_label):
		_gnomeui.gnome_property_box_append_page(self._o, child._o,
							tab_label._o)
_gtk._name2cls['GnomePropertyBox'] = GnomePropertyBox

class GnomeScores(GnomeDialog):
	get_type = _gnomeui.gnome_scores_get_type
	def __init__(self, scores=[], clear=_gtk.FALSE, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_scores_new(scores, clear)
	def set_logo_label(self, txt, font, color):
		_gnomeui.gnome_scores_set_logo_label(self._o, txt, font, color)
	def set_logo_pixmap(self, logo):
		_gnomeui.gnome_scores_set_logo_pixmap(self._o, logo)
	def set_logo_widget(self, w):
		_gnomeui.gnome_scores_set_logo_widget(self._o, w._o)
	def set_color(self, pos, color):
		_gnomeui.gnome_scores_set_color(self._o, pos, color)
	def set_def_color(self, color):
		_gnomeui.gnome_scores_set_def_color(self._o, color)
	def set_logo_label_title(self, txt):
		_gnomeui.gnome_scores_set_logo_label_title(self._o, txt)
	def set_current_player(self, pos):
		_gnomeui.gnome_scores_set_current_player(self._o, pos)
_gtk._name2cls['GnomeScores'] = GnomeScores

def scores_display(title, app_name, level=None, pos=-1):
	_gnomeui.gnome_scores_display(title, app_name, level, pos)

class GnomeSpell(_gtk.GtkVBox):
	get_type = _gnomeui.gnome_spell_get_type
	def __init__(self, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gnome_spell_new()
	def check(self, string):
		return _gnomeui.gnome_spell_check(self._o, string)
	def accept(self, word):
		_gnomeui.gnome_spell_accept(self._o, word)
	def insert(self, word, lowercase):
		_gnomeui.gnome_spell_insert(self._o, word, lowercase)
	def next(self):
		_gnomeui.gnome_spell_next(self._o)
	def kill(self):
		_gnomeui.gnome_spell_kill(self._o)
_gtk._name2cls['GnomeSpell'] = GnomeSpell

class GnomeStock(GnomePixmap):
	get_type = _gnomeui.gnome_stock_get_type
	def __init__(self, icon=None, _obj=None):
		if _obj: self._o = _obj; return
		if icon:
			self._o = _gnomeui.gnome_stock_new_with_icon(icon)
		else:
			self._o = _gnomeui.gnome_stock_new()
	def set_icon(self, icon):
		_gnomeui.gnome_stock_set_icon(self._o, icon)
_gtk._name2cls['GnomeStock'] = GnomeStock

def GnomeStockPixmapWidget(win, icon=None):
	print "Deprecated -- use GnomeStock instead of GnomeStockPixmapWidget"
	return GnomeStock(icon)

class GnomePixmapButton(_gtk.GtkButton):
	def __init__(self, pixmap, text, _obj=None):
		self._o = _gnomeui.gnome_pixmap_button(pixmap._o, text)

# these aren't really different types, but having different classes is easier
class GnomeStockButton(_gtk.GtkButton):
	def __init__(self, type):
		self._o = _gnomeui.gnome_stock_or_ordinary_button(type)
class GnomeStockMenuItem(_gtk.GtkMenuItem):
	def __init__(self, type, text):
		self.type = type
		self._o = _gnomeui.gnome_stock_menu_item(type, text)
	def get_accel(self):
		return _gnomeui.gnome_stock_menu_accel(self.type)
class GnomeStockTransparentWindow(_gtk.GtkWindow):
	def __init__(self, icon, subtype):
		self._o = _gnomeui.gnome_stock_transparent_window(icon,subtype)

def stock_menu_accel(type):
	return _gnomeui.gnome_stock_menu_accel(type)
def stock_menu_accel_parse(section):
	_gnomeui.gnome_stock_menu_accel_parse(section)

class GtkClock(_gtk.GtkLabel):
	get_type = _gnomeui.gtk_clock_get_type
	def __init__(self, type=CLOCK_REALTIME, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gnomeui.gtk_clock_new(type)
	def set_format(self, fmt):
		_gnomeui.gtk_clock_set_format(self._o, fmt)
	def set_seconds(self, seconds):
		_gnomeui.gtk_clock_set_seconds(self._o, seconds)
	def set_update_interval(self, seconds):
		_gnomeui.gtk_clock_set_update_interval(self._o, seconds)
	def start(self):
		_gnomeui.gtk_clock_start(self._o)
	def stop(self):
		_gnomeui.gtk_clock_stop(self._o)
_gtk._name2cls['GtkClock'] = GtkClock

class GtkDial(_gtk.GtkWidget):
	get_type = _gnomeui.gtk_dial_get_type
	def __init__(self, adj=None, _obj=None):
		if _obj: self._o = _obj; return
		if adj: adj = adj._o
		self._o = _gnomeui.gtk_dial_new(adj)
	def get_adjustment(self):
		return _obj2inst(_gnomeui.gtk_dial_get_adjustment(self._o))
	def set_update_policy(self, policy):
		_gnomeui.gtk_dial_set_update_policy(self._o, policy)
	def set_adjustment(self, adj):
		_gnomeui.gtk_dial_set_adjustment(self._o, adj._o)
	def set_percentage(self, pcnt):
		return _gnomeui.gtk_dial_set_percentage(self._o, pcnt)
	def get_percentage(self):
		return _gnomeui.gtk_dial_get_percentage(self._o)
	def set_value(self, value):
		return _gnomeui.gtk_dial_set_value(self._o, value)
	def get_value(self):
		return _gnomeui.gtk_dial_get_value(self._o)
	def set_view_only(self, view_only):
		_gnomeui.gtk_dial_set_view_only(self._o, view_only)
_gtk._name2cls['GtkDial'] = GtkDial

class GtkTed(_gtk.GtkTable):
	get_type = _gnomeui.gtk_ted_get_type
	def __init__(self, dialog_name='', layout=None, _obj=None):
		# last unnamed widget number
		self.__last = 0

		if _obj: self._o = _obj; return

		if layout == None:
			self._o = _gnomeui.gtk_ted_new(dialog_name)
		else:
			self._o = _gnomeui.gtk_ted_new_layout(dialog_name,
							      layout)
	def prepare(self):
		_gnomeui.gtk_ted_prepare(self._o)
	def add(self, child, name=None):
		if name == None:
			name = 'wid' + str(self.__last)
			self.__last = self.__last + 1
		_gnomeui.gtk_ted_add(self._o, child._o, name)
_gtk._name2cls['GtkTed'] = GtkTed


def dialog_cauldron(title, options, fmt, *args):
	return _gnomeui.gtk_dialog_cauldron(title, options, fmt, args)



#!/usr/bin/env python

# Author: Jesper Skov <jskov@cygnus.co.uk>
# A rewite of the C canvas example in the GNOME Developer's Information

import GDK
from gtk import *
from gnome.ui import *
from whrandom import *
import GdkImlib

class CanvasExample:
    def __init__(self):
        self.generator = whrandom()

        self.width = 400
        self.height = 400

        self.all = []

        self.colors = ("red",
                       "yellow",
                       "green",
                       "cyan",
                       "blue",
                       "magenta")


    def change_item_color(self, item):
        # Pick a random color from the list.
        n = int(self.generator.random() * len(self.colors)) - 1
        item.set(fill_color = self.colors[n])


    def item_event(self, widget, event=None):
        if event.type == GDK.BUTTON_PRESS:
            if event.button == 1:
                # Remember starting position.
                self.remember_x = event.x
                self.remember_y = event.y
                return TRUE

            elif event.button == 3:
                # Destroy the item.
                widget.destroy()
                return TRUE

        elif event.type == GDK._2BUTTON_PRESS:
            #Change the item's color.
            self.change_item_color(widget)
            return TRUE

        elif event.type == GDK.MOTION_NOTIFY:
            if event.state & GDK.BUTTON1_MASK:
                # Get the new position and move by the difference
                new_x = event.x
                new_y = event.y

                widget.move(new_x - self.remember_x, new_y - self.remember_y)

                self.remember_x = new_x
                self.remember_y = new_y

                return TRUE
            
        elif event.type == GDK.ENTER_NOTIFY:
            # Make the outline wide.
            widget.set(width_units=3)
            return TRUE

        elif event.type == GDK.LEAVE_NOTIFY:
            # Make the outline thin.
            widget.set(width_units=1)
            return TRUE

        return FALSE


    def add_object_clicked(self, widget, event=None):
        x1 = self.generator.random() * self.width
        y1 = self.generator.random() * self.height
        x2 = self.generator.random() * self.width
        y2 = self.generator.random() * self.height

        if x1 > x2:
            x2,x1 = x1,x2
        if y1 > y2:
            y2,y1 = y1,y2

        if (x2 - x1) < 10:
            x2 = x2 + 10

        if (y2 - y1) < 10:
            y2 = y2 + 10

        if (self.generator.random() > .5):
            type = 'rect'
        else:
            type = 'ellipse'

        w = self.canvas.root().add(type, x1=x1, y1=y1, x2=x2, y2=y2, 
                                   fill_color='white', outline_color='black',
                                   width_units=1.0)
        w.connect("event", self.item_event)

        self.all.append(w)

    def main(self):
        # Open window to hold canvas.
        win = GtkWindow()
        win.connect('destroy', mainquit)
        win.set_title('Canvas Example')

        # Create VBox to hold canvas and buttons.
        vbox = GtkVBox()
        win.add(vbox)
        vbox.show()

	# Some instructions for people using the example:
	label = GtkLabel("Drag - move object.\n" +
			 "Double click - change colour\n" +
			 "Right click - delete object")
	vbox.pack_start(label, expand=FALSE)
	label.show()

        # Create canvas.
        self.canvas = GnomeCanvas()
        self.canvas.set_usize(self.width, self.height)
        self.canvas.set_scroll_region(0,0, self.width, self.height)
        vbox.pack_start(self.canvas)
        self.canvas.show()

        # Create buttons.
        hbox = GtkHBox()
        vbox.pack_start(hbox, expand=FALSE)
        hbox.show()

        b = GtkButton("Add an object")
        b.connect("clicked", self.add_object_clicked)
        hbox.pack_start(b)
        b.show()

        b = GtkButton("Quit")
        b.connect("clicked", mainquit)
        hbox.pack_start(b)
        b.show()

        win.show()

if __name__ == '__main__':
    c = CanvasExample()
    c.main()
    mainloop()



import gnome.applet
import gtk
import time

def update_label():
	str = time.strftime("%a %b %d\n%I:%M %p", time.localtime(time.time()))
	label.set_text(str)
	return gtk.TRUE

app = gnome.applet.AppletWidget("python-clock")

frame = gtk.GtkFrame()
label = gtk.GtkLabel()
label.set_padding(4,4)
update_label()

frame.add(label)
label.show()

frame.show()
app.add(frame)
app.set_tooltip("Python clock")
app.show()

gtk.timeout_add(60, update_label)

gtk.mainloop()




#!/usr/bin/env python
#
# This is an applet that displays your Netscape 4.x bookmarks on its context
# menu.  When you select a bookmark from the context menu, it will load it
# in netscape (or whatever other browser you have set to run when
# gnome_url_show is called).
#
import os
filename = os.path.join(os.environ['HOME'], '.netscape', 'bookmarks.html')
# Or for mozilla bookmarks ...
#filename = os.path.join(os.environ['HOME'], '.mozilla', 'bookmarks.html')

import gnome.applet
import gnome.url
from gtk import *
from gnome.ui import *
from sgmllib import SGMLParser

class BookmarkParser(SGMLParser):
	"""Parses a Netscape 4.x style bookmarks file"""

	def __init__(self, verbose=0):
		SGMLParser.__init__(self, verbose)
		self.title = None
		self.data = ""
		self.rootmenu = None
		self.menuheader = None
		self.is_menuheader = 0
		self.treestack = []

		self.item_title = None
		self.item_href = None

	def handle_data(self, data):
		self.data = self.data + data

	def start_title(self, attrs): self.data = ""
	def end_title(self): self.title = self.data

	def start_dl(self, attrs):
		newmenu = []
		if len(self.treestack) > 0:
			self.treestack[-1].append((self.item_title, newmenu))
			self.treestack.append(newmenu)
		else:
			self.treestack.append(newmenu)
			self.rootmenu = newmenu
		if self.is_menuheader: self.menuheader = newmenu
	def end_dl(self):
		del self.treestack[-1]
		
	def start_h3(self, attrs):
		self.data = ""
		self.is_menuheader = 0
		for tag, value in attrs:
			if tag == 'menuheader': self.is_menuheader = 1
	def end_h3(self): self.item_title = self.data

	def start_a(self, attrs):
		self.data = ""
		for tag, value in attrs:
			if tag == 'href':
				self.item_href = value
	def end_a(self):
		self.treestack[-1].append((self.data, self.item_href))

def parseBookmarks(fname):
	"""parses a bookmarks file, and returns the parse tree"""
	fp = open(fname)
	p = BookmarkParser()
	p.feed(fp.read())
	fp.close()
	p.close()
	return (p.title, p.menuheader or p.rootmenu)

def url_callback(applet, url):
	gnome.url.show(url)
def register_callbacks(app, list, prefix="bookmarks"):
	num = 0
	for title, href in list:
		key = prefix + "/menu" + str(num)
		if type(href) == type([]):
			app.register_stock_callback_dir(key,
							STOCK_MENU_BOOK_OPEN,
							title)
			register_callbacks(app, href, key)
		else:
			app.register_stock_callback(key, STOCK_MENU_JUMP_TO,
						    title, url_callback, href)
		num = num + 1
def fill_menu(app, title, menu):
	app.set_tooltip(title)
	app.register_stock_callback_dir("bookmarks", STOCK_MENU_BOOK_OPEN,
					"Bookmarks")
	register_callbacks(app, menu)

app = gnome.applet.AppletWidget("bookmarks")

frame = GtkFrame()
frame.set_shadow_type(SHADOW_ETCHED_IN)
label = GtkLabel("Netscape\nBookmarks")
label.set_padding(4,4)
frame.add(label)
label.show()
frame.show()

app.add(frame)
app.show()

title, menu = parseBookmarks(filename)
fill_menu(app, title, menu)

mainloop()




#!/usr/bin/env python

# Author: Chi-Deok Hwang <cdhwang@sr.hei.co.kr>
# A translation of the puzzle example using the canvas.

from gtk import *
from gnome.ui import *
from GDK import *
import whrandom

PIECE_SIZE = 50

def test_win (board):
	for i in range(15):
		if not board[i] or board[i].get_data('piece_num') != i: return
	dlg=GnomeOkDialog('You stud, you win!')
	dlg.set_modal(TRUE)
	dlg.run()
	return
def get_piece_color(piece):
	y,x=divmod(piece, 4)
	r = ((4-x) * 255) / 4
	g = ((4-y) * 255) / 4
	b = 128
	return "#%02x%02x%02x" % (r, g, b)

def piece_event (item, event, canvas):
	if event.type == ENTER_NOTIFY:
		text = item.get_data ('text')
		text.set (fill_color='white')
	elif event.type == LEAVE_NOTIFY:
		text = item.get_data ('text')
		text.set (fill_color='black')
	elif event.type == BUTTON_PRESS:
		board = canvas.get_data ('board')
		num = item.get_data ('piece_num')
		pos = item.get_data ('piece_pos')
		y,x = divmod(pos, 4)
		move = TRUE
		if y > 0 and not board[(y-1)*4+x]:
			dx = 0.0; dy = -1.0; y = y - 1
		elif y < 3 and not board[(y+1)*4+x]:
			dx = 0.0; dy = 1.0; y = y + 1
		elif x > 0 and not board[y*4 + x-1]:
			dx = -1.0;dy = 0.0; x = x - 1
		elif x < 3 and not board[y*4 + x + 1]:
			dx = 1.0;dy = 0.0;x = x + 1
		else: 
			move = FALSE
		if move:
			newpos = y*4 + x
			board[pos] = None
			board[newpos] = item
			item.move (dx*PIECE_SIZE, dy*PIECE_SIZE)
			item.set_data ('piece_pos', newpos)
			test_win(board)
	return 1

def scramble(obj, canvas):
	SCRAMBLE_MOVES = 256
	board = canvas.get_data('board')
	pos = board.index(None)
	for i in range(SCRAMBLE_MOVES):
		while 1:
			dir = whrandom.randint(0,3)
			x = y = 0
			if dir == 0 and pos > 3:
				y = -1
			elif dir == 1 and pos < 12:
				y = 1
			elif dir == 2 and pos%4:
				x = -1
			elif dir == 3 and pos%4 != 3:
				x = 1
			else:
				continue
			break
		oldpos = pos + y*4 + x
		board[pos] = board[oldpos]
		board[oldpos] = None
		board[pos].set_data('piece_pos', pos)
		board[pos].move (-x*PIECE_SIZE,-y*PIECE_SIZE)
		canvas.update_now()
		pos = oldpos


def create_fifteen():
	win = GtkWindow()
	win.connect('destroy', mainquit)
	win.set_title('Canvas Fifteen')

	vbox = GtkVBox(spacing=4)
	vbox.set_border_width(4)
	win.add (vbox)

	align = GtkAlignment(xa=0.5,ya=0.5)
	vbox.pack_start(align)

	frame = GtkFrame()
	frame.set_shadow_type(SHADOW_IN)
	align.add (frame)

	canvas = GnomeCanvas()
	canvas.set_usize (PIECE_SIZE * 4 + 1, PIECE_SIZE * 4 + 1)
	canvas.set_scroll_region (0, 0, PIECE_SIZE * 4 + 1, PIECE_SIZE * 4 + 1)
	frame.add (canvas)

	board = []
	canvas.set_data ('board', board)
	root = canvas.root()
	for i in range(15):
		y,x = divmod(i, 4)
		group = root.add('group')
		group.move(x*PIECE_SIZE, y*PIECE_SIZE)
		board.append(group)
		group.add('rect', x1=0.0,y1=0.0,
			  x2=PIECE_SIZE,y2=PIECE_SIZE,
			  fill_color=get_piece_color(i),
			  outline_color='black',
			  width_pixels=0)
		text = group.add('text', text="%d" % (i + 1),
			  x=PIECE_SIZE/2.0, y=PIECE_SIZE/2.0,
			  font='-adobe-helvetica-bold-r-normal--24-240-75-75-p-*-iso8859-1',
			  anchor=ANCHOR_CENTER,
			  fill_color='black') 
		group.set_data ('piece_num', i)
		group.set_data ('piece_pos', i)
		group.set_data ('text', text)
		group.connect ('event', piece_event, canvas)
	board.append (None)

	button = GtkButton('Scramble')
	vbox.pack_start (button, expand=FALSE, fill=FALSE)
	button.set_data ('board', board)
	button.connect ('clicked', scramble, canvas)

	win.show_all()

create_fifteen()

mainloop()




import sys
if sys.version[:3] == '1.4':
	import ni

from gtk import *
from gnome.ui import *

def clicked(_button):
	print "Button clicked"

def xrandom_widgets(ted):
	for i in range(4):
		name = "Button-%d" % (i,)
		l = GtkButton(name)
		l.show()
		ted.add(l, name)
		l.connect('clicked', clicked)
	l = GtkLabel("This is a windowless widget")
	l.show()
	ted.add(l, "Label-0")
	l = GtkEntry()
	l.show()
	ted.add(l, "Entry-0")

def main():
	w = GtkWindow()
	w.connect('delete_event', mainquit)
	ted = GtkTed("DialogName")
	ted.show()
	w.add(ted)

	xrandom_widgets(ted)
	ted.prepare()
	w.show()
	mainloop()

if __name__ == '__main__': main()




import _gnome, gnome

if not gnome.gnomelib_init_called:
	_gnome.gnomelib_init(gnome.app_id, gnome.app_version)
	gnome.gnomelib_init_called = 1

def file_find_file(app, path):
	return _gnome.gnome_help_file_find_file(app, path)
def file_path(app, path):
	return _gnome.gnome_help_file_path(app, path)
def display(ref_name, ref_path):
	_gnome.gnome_help_display(ref_name, ref_path)
def goto(url):
	_gnome.gnome_help_goto(url)



# python-gnome-about
# Vincent Renardias <vincent@ldsol.com>, 1999/09/10

from gtk import *
from gnome.ui import *
from GDK import *

about = GnomeAbout('Title', 'Version', 'Copyright', ['Author1', 'Author2', '...'], 'Comments')

about.connect('destroy', mainquit)

about.show()

mainloop()




import _gnome, gnome

if not gnome.gnomelib_init_called:
	_gnome.gnomelib_init(gnome.app_id, gnome.app_version)
	gnome.gnomelib_init_called = 1

_gnome.gnome_score_init(gnome.app_id)

def log(score, level, high_to_low):
	_gnome.gnome_score_log(score, level, high_to_low)
def get_notable(gamename=None, level=None):
	return _gnome.gnome_score_get_notable(gamename, level)




# python-gnome-calculator
# Vincent Renardias <vincent@ldsol.com>, 1999/09/10

from gtk import *
from gnome.ui import *
from GDK import *

window = GtkWindow(type='toplevel')
window.connect('destroy', mainquit)

calc = GnomeCalculator()
window.add(calc)

window.show_all()

mainloop()




import gtk; _gtk = gtk; del gtk
import _zvt

_obj2inst = _gtk._obj2inst

# selection types for get_buffer ...
SELTYPE_NONE  = 0
SELTYPE_CHAR  = 1
SELTYPE_WORD  = 2
SELTYPE_LINE  = 3
SELTYPE_MAGIC = 4

class ZvtTerm(_gtk.GtkWidget):
	get_type = _zvt.zvt_term_get_type
	def __init__(self, cols=-1, rows=-1, _obj=None):
		if _obj: self._o = _obj; return
		if cols != -1 and rows != -1:
			self._o = _zvt.zvt_term_new_with_size(cols, rows)
		else:
			self._o = _zvt.zvt_term_new()
	def __getattr__(self, attr):
		if attr == 'adjustment':
			return _gtk.GtkAdjustment(_obj=
					_zvt.zvt_term_get_adjustment(self._o))
		elif attr == 'charwidth':
			return _zvt.zvt_term_get_charwidth(self._o)
		elif attr == 'charheight':
			return _zvt.zvt_term_get_charheight(self._o)
		return _gtk.GtkWidget.__getattr__(self, attr)
	def reset(self, hard):
		_zvt.zvt_term_reset(self._o, hard)
	def feed(self, text):
		_zvt.zvt_term_feed(self._o, text)
	def forkpty(self, do_uwtmp_log=_gtk.FALSE):
		return _zvt.zvt_term_forkpty(self._o, do_uwtmp_log)
	def closepty(self):
		return _zvt.zvt_term_closepty(self._o)
	def killchild(self, signal):
		return _zvt.zvt_term_killchild(self._o, signal)
	def bell(self):
		_zvt.zvt_term_bell(self._o)
	def set_scrollback(self, lines):
		_zvt.zvt_term_set_scrollback(self._o, lines)
	def get_buffer(self, type, sx,sy, ex,ey):
		return _zvt.zvt_term_get_buffer(self._o, type, sx,sy, ex,ey)
	def set_font_name(self, name):
		_zvt.zvt_term_set_font_name(self._o, name)
	def set_fonts(self, font, font_bold):
		_zvt.zvt_term_set_fonts(self._o, font, font_bold)
	def hide_pointer(self):
		_zvt.zvt_term_hide_pointer(self._o)
	def show_pointer(self):
		_zvt.zvt_term_show_pointer(self._o)
	def set_bell(self, state):
		_zvt.zvt_term_set_bell(self._o, state)
	def get_bell(self):
		return _zvt.zvt_term_get_bell(self._o)
	def set_blink(self, state):
		_zvt.zvt_term_set_blink(self._o, state)
	def set_scroll_on_keystroke(self, state):
		_zvt.zvt_term_set_scroll_on_keystroke(self._o, state)
	def set_scroll_on_output(self, state):
		_zvt.zvt_term_set_scroll_on_output(self._o, state)
	# color_list is a list of 18 (r,g,b) 3-tuples
	def set_color_scheme(self, color_list):
		_zvt.zvt_term_set_color_scheme(self._o, color_list)
	def set_default_color_scheme(self):
		_zvt.zvt_term_set_default_color_scheme(self._o)
	def set_del_key_swap(self, state):
		_zvt.zvt_term_set_del_key_swap(self._o, state)
	def set_wordclass(self, wordclass):
		_zvt.zvt_term_set_wordclass(self._o, wordclass)
	def match_add(self, regex, highlight_mask):
		return _zvt.zvt_term_match_add(self._o, regex,
					       highlight_mask, None)
	def match_clear(self, regex):
		_zvt.zvt_term_match_clear(self._o, regex)
	def match_check(self, x, y):
		return _zvt.zvt_term_match_check(self._o, x, y)
	def set_background(self, pixmap_file, transparent=_gtk.FALSE,
			   shaded=_gtk.FALSE):
		_zvt.zvt_term_set_background(self._o, pixmap_file, transparent,
					     shaded)
	def set_shadow_type(self, shadow_type):
		_zvt.zvt_term_set_shadow_type(self._o, shadow_type)
	def set_size(self, width, height):
		_zvt.zvt_term_set_size(self._o, width, height)
	def writechild(self, text):
		_zvt.zvt_term_writechild(self._o, text)
_gtk._name2cls['ZvtTerm'] = ZvtTerm



import _gnome, gnome

if not gnome.gnomelib_init_called:
	_gnome.gnomelib_init(gnome.app_id, gnome.app_version)
	gnome.gnomelib_init_called = 1

def recently_used(filename, filetype, creator, desc):
	_gnome.gnome_history_recently_used(filename, filetype, creator, desc)
def get_recently_used():
	return _gnome.gnome_history_get_recently_used()



import sys
if sys.version[:3] == '1.4':
	import ni
import os
import urllib, urlparse
from gtk import *
from gnome.ui import *
from gnome.xmhtml import *

opener = urllib.URLopener()

# url history
history = []
# links for 'forward'
forward = []

def about(button):
	GnomeAbout('GtkXmHTML Test', '0.0',
		   'May be distributed under the terms of the GPL2',
		   ['James Henstridge'],
		   'This is a useless application demonstrating the\n' +
		   'GtkXmHTML widget with python.').show()

def load_url(url):
	if os.path.exists(url):
		f = open(url)
	else:
		f = opener.open(url)
		headers = f.info()
		mime = headers.getheader('Content-type')
		if mime: html.set_mime_type(mime)
	source = f.read()
	html.freeze()
	html.source(source)
	html.thaw()
	history.append(url)

def anchor_track(html, info):
	if info.href:
		full_url = urlparse.urljoin(history[-1], info.href)
		status.set_text(full_url)
	else:
		status.set_text('')

def activate(html, info):
	if info.href:
		url = urlparse.urljoin(history[-1], info.href)
		load_url(url)
		entry.set_text(url)
		status.set('')

def key_function(entry, event):
	url = entry.get_text()
	if event.keyval == GDK.Return:
		load_url(url)
		del forward[:]
		entry.emit_stop_by_name('key_press_event')

def do_back(_b):
	forward.append(history[-1])
	del history[-1]
	url = history[-1]
	del history[-1]
	load_url(url)
def do_forward(_b):
	if len(forward) == 0: return
	load_url(forward[-1])
	del forward[-1]
def do_reload(_b):
	if len(history) == 0: return
	url = history[-1]
	del history[-1]
	load_url(url)

file_menu = [
	UIINFO_ITEM_STOCK('Quit', None, mainquit, STOCK_MENU_QUIT),
]
help_menu = [
	UIINFO_ITEM_STOCK('About...', None, about, STOCK_MENU_ABOUT),
]
menus = [
	UIINFO_SUBTREE('File', file_menu),
	UIINFO_SUBTREE('Help', help_menu)
]

toolbar = [
	UIINFO_ITEM_STOCK('Back', 'Previous page', do_back, STOCK_PIXMAP_BACK),
	UIINFO_ITEM_STOCK('Forward', 'Next page', do_forward,
			  STOCK_PIXMAP_FORWARD),
	UIINFO_ITEM_STOCK('Reload', 'Reload current page', do_reload,
			  STOCK_PIXMAP_REFRESH)
]

win = GnomeApp("html_demo", "Python Gtk-XmHTML Test")
win.set_wmclass("gtk_xmhtml_test", "GtkXmHTMLTest")
win.connect('delete_event', mainquit)

vbox = GtkVBox(spacing=3)
vbox.set_border_width(2)
vbox.show()
win.set_contents(vbox)

entry = GtkEntry()
entry.connect('key_press_event', key_function)
vbox.pack_start(entry, expand=FALSE)
entry.show()

html = GtkXmHTML()
html.set_dithering(FALSE)  # this forces creation of CC
html.set_usize(400, 400)
html.set_allow_body_colors(TRUE)
html.connect("anchor_track", anchor_track)
html.connect("activate", activate)

html.freeze()
html.source('''<html><head><title>Dummy Document</title></head>
<body bgcolor="#ffffff"><H1>Pick a URL</H1>
Use the entry box to pick a document to view.
Currently image loading does not work.
Also you will find the links
aren't working.  This is because I haven't found
enough hooks to get everything working in gtk-xmhtml
</body></html>''')
html.thaw()
vbox.pack_start(html)
html.show()

sep = GtkHSeparator()
vbox.pack_start(sep, expand=FALSE)
sep.show()

status = GtkLabel('')
status.set_justify(JUSTIFY_LEFT)
status.set_alignment(0.0, 0.5)
win.set_statusbar(status)
status.show()

# This is at the end, since pixmap creation changes the default visual
win.create_menus(menus)
win.create_toolbar(toolbar)

win.show()

mainloop()




"""A module that should help create the affine transformations you would use
for transforming GnomeCanvas items.

As a little background, an affine transformation is a linear transformation
and a translation.  The linear transformationcan be represented by a matrix
and the translation by a vector.  So a general affine transformation looks
like this:
   [ x ] -> [ a b ][ x ] + [ e ]
   [ y ]    [ c d ][ y ]   [ f ]

As you can see, the affine transformation is defined by the six numbers in
the matrix and column vector.  For the GnomeCanvas item functions, affine
transformations are represented by a flat sequence of the form
  (a, c, b, d, e, f)
  
This module attempts to make it easy to create complex affine transformations
from simpler ones like rotation, scaling and translation.
"""

import math

# These functions create base affine transformations that can be used to build
# more complex ones.

def identity():
	"""The identity affine transformation"""
	return (1, 0, 0, 1, 0, 0)

def scale(sx=1, sy=1):
	"""Scale by a factor of sx in the X direction and sy in Y direction"""
	return (sx, 0, 0, sy, 0, 0)

def rotate(radians=None, degrees=0):
	"""Rotate in either degrees or radians"""
	if not radians: radians = degrees * math.pi / 180.0
	s = math.sin(radians)
	c = math.cos(radians)
	return (c, s, -s, c, 0, 0)

def shear(xshear=0, yshear=0):
	"""Creates a shear transformation in either X and/or Y directoion"""
	return (1, yshear, xshear, 1, 0, 0)

def translate(tx=0, ty=0):
	"""Translate by (tx,ty)"""
	return (1, 0, 0, 1, tx, ty)


# These functions can be used to combine or manipulate other affine
# tranformations

def compose(a1, *affines):
	"""Compose a number of affine transformations together

	If the affines a1,a2,a3 are passed as arguments, then the resulting
	affine A will give A(x) == a1(a2(a3(x)))"""
	if affines == (): return a1
	a2 = apply(compose, affines)
	return (a1[0]*a2[0] + a1[2]*a2[1],
		a1[1]*a2[0] + a1[3]*a2[1],
		a1[0]*a2[2] + a1[2]*a2[3],
		a1[1]*a2[2] + a1[3]*a2[3],
		a1[0]*a2[4] + a1[2]*a2[5] + a1[4],
		a1[1]*a2[4] + a1[3]*a2[5] + a1[5])

def invert(aff):
	det_inv = 1 / (aff[0]*aff[3] - aff[1]*aff[2])
	return (aff[3]  * det_inv,
		-aff[1] * det_inv,
		-aff[2] * det_inv,
		aff[0]  * det_inv,
		(aff[2]*aff[5] - aff[3]*aff[4]) * det_inv,
		(aff[1]*aff[4] - aff[0]*aff[5]) * det_inv)




import sys
if sys.version[:3] == "1.4":
	import ni

from gtk import *
from gnome.ui import *

def about(item):
	win = GnomeAbout('Test', '0.0', 'GPL', ['James Henstridge'],
			 'a simple program to test pygimp')
	win.show()
def cb(item):
	print item

file_menu = [
	(APP_UI_ITEM, 'New...', None, cb, None,
	 APP_PIXMAP_STOCK, STOCK_MENU_NEW, 0, 0),
	(APP_UI_ITEM, 'Open', None, cb, None,
	 APP_PIXMAP_STOCK, STOCK_MENU_OPEN, 0, 0),
	(APP_UI_ITEM, 'Save', None, cb, None,
	 APP_PIXMAP_STOCK, STOCK_MENU_SAVE, 0, 0),
	(APP_UI_ITEM, 'Save As', None, cb, None,
	 APP_PIXMAP_STOCK, STOCK_MENU_SAVE_AS, 0, 0),
	UIINFO_SEPARATOR,
	(APP_UI_ITEM, 'Exit', None, mainquit, None,
	 APP_PIXMAP_STOCK, STOCK_MENU_EXIT, 0, 0)
]
edit_menu = [
	(APP_UI_ITEM, 'Cut', None, cb, None,
	 APP_PIXMAP_STOCK, STOCK_MENU_CUT, 0, 0),
	(APP_UI_ITEM, 'Copy', None, cb, None,
	 APP_PIXMAP_STOCK, STOCK_MENU_COPY, 0, 0),
	(APP_UI_ITEM, 'Paste', None, cb, None,
	 APP_PIXMAP_STOCK, STOCK_MENU_PASTE, 0, 0),
]
test_menu = [
	UIINFO_ITEM('an item before radio list', None, None, None),
	UIINFO_SEPARATOR,
	UIINFO_RADIOLIST([
		UIINFO_ITEM('one', None, None, None),
		UIINFO_ITEM('two', None, None, None),
		UIINFO_ITEM('three', None, None, None)
	]),
	UIINFO_ITEM('An item after radio list', None, None, None)
]

help_menu = [
	UIINFO_HELP('sample-help'),
	UIINFO_SEPARATOR,
	(APP_UI_ITEM, 'About', None, about, None,
	 APP_PIXMAP_STOCK, STOCK_MENU_ABOUT, 0, 0),
]
menu = [
	UIINFO_SUBTREE('File', file_menu),
	UIINFO_SUBTREE('Edit', edit_menu),
	UIINFO_SUBTREE('Test', test_menu),
	UIINFO_SUBTREE('Help', help_menu)
]

app = GnomeApp('uiinfo_demo', 'UIInfo Demo')
app.connect('delete_event', mainquit)
app.create_menus(menu)
app.show()

mainloop()




import _gnome, gnome

if not gnome.gnomelib_init_called:
	_gnome.gnomelib_init(gnome.app_id, gnome.app_version)
	gnome.gnomelib_init_called = 1

_gnome.gnome_triggers_init()

GTRIG_NONE      = 0
GTRIG_FUNCTION  = 1 # unsupported
GTRIG_COMMAND   = 2
GTRIG_MEDIAPLAY = 3

#def readfile(filename):
#	_gnome.gnome_triggers_readfile(filename)
def add_trigger(trig_type, trig_arg, trig_level, *supinfo):
	_gnome.gnome_triggers_add_trigger(trig_type, trig_arg, trig_level,
					  supinfo)
def vadd_trigger(trig_type, trig_arg, trig_level, supinfo):
	_gnome.gnome_triggers_add_trigger(trig_type, trig_arg, trig_level,
					  supinfo)
def do(msg, level, *supinfo):
	_gnome.gnome_triggers_do(msg, level, supinfo)
def vdo(msg, level, supinfo):
	_gnome.gnome_triggers_do(msg, level, supinfo)



#!/usr/bin/env python
import sys
import os
import urllib, urlparse
from gtk import *
from gnome.ui import *
from gtkhtml import *
import signal
signal.signal(signal.SIGINT, signal.SIG_DFL)

opener = urllib.URLopener()

# url history
history = []
# links for 'forward'
forward = []

def about(button):
	GnomeAbout('GtkHTML Test', '0.0',
		   'May be distributed under the terms of the GPL2',
		   ['Matt Wilson'],
		   ('This is a useless application demonstrating the\n'
                    'GtkHTML widget with python.  Based on html_demo.py by'
                    'James Henstridge')).show()

class HtmlWindow(GtkHTML):
	def __init__(self):
		GtkHTML.__init__(self)
	
	def load_url(self, html, url):
		if history: url = urllib.basejoin(history[-1], url)
		print "load_url", url
		history.append(url)
		handle = html.begin()
		self.request_url(html, url, handle)
		html.end(handle, HTML_STREAM_OK)

	def request_url(self, html, url, handle):
		url = urllib.basejoin(history[-1], url)
		print "Requesting url", url
		if url == 'blank':
			print "here"
			source = "<html><body>foobar</body></html>"
		elif os.path.exists(url):
			f = open(url)
			source = f.read()
		else:
			try:
				f = opener.open(url)
			except IOError, (num, error):
				GnomeErrorDialog(error).run()
				# html.end(handle, HTML_STREAM_ERROR)
				return
			headers = f.info()
			mime = headers.getheader('Content-type')
			source = f.read()
		html.write(handle, source)
		

	def anchor_track(self, html, info):
		if info.href:
			full_url = urlparse.urljoin(history[-1], info.href)
			status.set_text(full_url)
		else:
			status.set_text('')

	def activate(self, html, info):
		if info.href:
			url = urlparse.urljoin(history[-1], info.href)
			self.load_url(html, url)
			entry.set_text(url)
			status.set('')

	def entry_activate(self, entry, html):
		url = entry.get_text()
		self.load_url(html, url)
		del forward[:]

	def do_back(self, _b):
		forward.append(history[-1])
		del history[-1]
		url = history[-1]
		del history[-1]
		self.load_url(html, url)

	def do_forward(self, _b):
		if len(forward) == 0: return
		self.load_url(html, forward[-1])
		del forward[-1]

	def do_reload(self, _b):
		if len(history) == 0: return
		url = history[-1]
		del history[-1]
		self.load_url(html, url)

html = HtmlWindow()

file_menu = [
	UIINFO_ITEM_STOCK('Quit', None, mainquit, STOCK_MENU_QUIT),
]
help_menu = [
	UIINFO_ITEM_STOCK('About...', None, about, STOCK_MENU_ABOUT),
]
menus = [
	UIINFO_SUBTREE('File', file_menu),
	UIINFO_SUBTREE('Help', help_menu)
]

toolbar = [
	UIINFO_ITEM_STOCK('Back', 'Previous page', html.do_back, STOCK_PIXMAP_BACK),
	UIINFO_ITEM_STOCK('Forward', 'Next page', html.do_forward,
			  STOCK_PIXMAP_FORWARD),
	UIINFO_ITEM_STOCK('Reload', 'Reload current page', html.do_reload,
			  STOCK_PIXMAP_REFRESH)
]

win = GnomeApp("html_demo", "Python GtkHTML Test")
win.set_wmclass("gtk_html_test", "GtkHTMLTest")
win.connect('delete_event', mainquit)

vbox = GtkVBox(spacing=3)
vbox.set_border_width(2)
vbox.show()
win.set_contents(vbox)

entry = GtkEntry()
html.connect('url_requested', html.request_url)
html.connect('link_clicked', html.load_url)

entry.connect('activate', html.entry_activate, html)
vbox.pack_start(entry, expand=FALSE)
entry.show()

html.set_usize(400, 400)

sw = GtkScrolledWindow()
sw.set_policy(POLICY_AUTOMATIC, POLICY_AUTOMATIC)
sw.add(html)
vbox.pack_start(sw)

sep = GtkHSeparator()
vbox.pack_start(sep, expand=FALSE)

status = GtkLabel('')
status.set_justify(JUSTIFY_LEFT)
status.set_alignment(0.0, 0.5)
win.set_statusbar(status)

# This is at the end, since pixmap creation changes the default visual
win.create_menus(menus)
win.create_toolbar(toolbar)

html.load_empty()

win.show_all()

mainloop()



import gtk; _gtk = gtk; del gtk
import _gtkhtml

HTML_STREAM_OK = 0
HTML_STREAM_ERROR = 1

class GtkHTML (_gtk.GtkLayout):
    get_type = _gtkhtml.gtk_html_get_type
    def __init__ (self, _obj=None):
        if _obj: self._o = _obj; return
        self._o = _gtkhtml.gtk_html_new ()

    def allow_selection (self, allow):
        _gtkhtml.gtk_html_allow_selection (self._o, allow)

    def select_word (self):
        _gtkhtml.gtk_html_select_word (self._o)

    def select_line (self):
        _gtkhtml.gtk_html_select_line (self._o)

    def begin (self):
        return _gtkhtml.gtk_html_begin (self._o)

    def begin_content (self, content_type):
        return _gtkhtml.gtk_html_begin_content (self._o, content_type)

    def write (self, handle, buf):
        _gtkhtml.gtk_html_write (self._o, handle, buf)

    def end (self, handle, status):
        _gtkhtml.gtk_html_end (self._o, handle, status)

    def load_empty (self):
        _gtkhtml.gtk_html_load_empty (self._o)

    def load_from_string (self, buf):
        _gtkhtml.gtk_html_load_from_string (self._o, buf)

    def get_title (self):
        return _gtkhtml.gtk_html_get_title (self._o)

    def jump_to_anchor (self, anchor):
        return _gtkhtml.gtk_html_jump_to_anchor (self._o, anchor)

    def set_default_background_color (self, colour):
        _gtkhtml.gtk_html_set_default_background_color (self._o, colour)

    def set_default_content_type (self, content_type):
        _gtkhtml.gtk_html_set_default_content_type (self._o, content_type)

_gtk._name2cls['GtkHTML'] = GtkHTML

class GtkHTMLEmbedded (_gtk.GtkBin):
    get_type = _gtkhtml.gtk_html_embedded_get_type
    def __init__ (self, classid='', name='', type='', data='', width=-1, height=-1, _obj=None):
        if _obj: self._o = _obj; return
        self._o = _gtkhtml.gtk_html_embedded_new (classid, name, type, data, width, height)

    def set_parameter (self, param, value):
        _gtkhtml.gtk_html_embedded_set_parameter (self._o, param, value)

    def get_parameter (self, param):
        return _gtkhtml.gtk_html_embedded_get_parameter (self._o, param)

    def set_descent (self, descent):
        _gtkhtml.gtk_html_embedded_set_descent (self._o, descent)

    def __getattr__ (self, attr):
        attrs = {
            'classid': _gtkhtml.gtk_html_embedded_get_object_classid,
            'name': _gtkhtml.gtk_html_embedded_get_object_name,
            'type': _gtkhtml.gtk_html_embedded_get_object_type,
            'data': _gtkhtml.gtk_html_embedded_get_object_data
        }
        if attrs.has_key(attr):
            return attrs[attr](self._o)
        return _gtk.GtkBin.__getattr__(self, attr)

    def __setattr__ (self, attr, value):
        attrs = {
            'classid': _gtkhtml.gtk_html_embedded_set_object_classid,
            'name': _gtkhtml.gtk_html_embedded_set_object_name,
            'type': _gtkhtml.gtk_html_embedded_set_object_type,
            'data': _gtkhtml.gtk_html_embedded_set_object_data
        }
        if attrs.has_key(attr):
            attrs[attr](self._o, value)
        else:
            self.__dict__[attr] = value

    def __delattr__ (self, attr):
        attrs = {
            'classid': _gtkhtml.gtk_html_embedded_set_object_classid,
            'name': _gtkhtml.gtk_html_embedded_set_object_name,
            'type': _gtkhtml.gtk_html_embedded_set_object_type,
            'data': _gtkhtml.gtk_html_embedded_set_object_data
        }
        if attrs.has_key(attr):
            attrs[attr](self._o, None)
        else:
            del self.__dict__[attr]
        
_gtk._name2cls['GtkHTMLEmbedded'] = GtkHTMLEmbedded




import _gnome, gnome

if not gnome.gnomelib_init_called:
	_gnome.gnomelib_init(gnome.app_id, gnome.app_version)
	gnome.gnomelib_init_called = 1

def convert_stream(fd, fromtype, totype):
	return _gnome.gnome_file_convert_stream(fd, fromtype, totype)
def convert(filename, fromtype, totype):
	return _gnome.gnome_file_convert(filename, fromtype, totype)



import gtk; _gtk = gtk; del gtk
import _gtkxmhtml

class XmHTMLCallbackStruct:
	def __init__(self, cobject):
		for key, value in _gtkxmhtml.cobject_to_info(cobject).items():
			setattr(self, key, value)
		if hasattr(self, 'html'):
			self.html = _gtk._obj2inst(self.html)
_XmHTMLCallbackStruct = XmHTMLCallbackStruct
del XmHTMLCallbackStruct

class GtkXmHTML(_gtk.GtkContainer):
	get_type = _gtkxmhtml.gtk_xmhtml_get_type
	def __init__(self, _obj=None):
		if _obj: self._o = _obj; return
		self._o = _gtkxmhtml.gtk_xmhtml_new()
	class __cnv:
		def __init__(self, func):
			self.func = func
		def __call__(self, *args):
			return apply(self.func, (_gtk._obj2inst(args[0]),
					_XmHTMLCallbackStruct(args[1])))
	def connect(self, sig_name, handler):
		if sig_name in ("activate", "arm", "anchor_track", "frame",
				"form", "input", "link", "motion", "imagemap",
				"document", "focus", "losing_focus",
				"motion_track", "html_event"):
			callback = self.__cnv(handler)
			return _gtk._gtk.gtk_signal_connect(self._o, sig_name,
							    callback.__call__)
		else:
			_gtk.GtkContainer.connect(self, sig_name, handler)
	signal_connect = connect
	def connect_after(self, sig_name, handler):
		if sig_name in ("activate", "arm", "anchor_track", "frame",
				"form", "input", "link", "motion", "imagemap",
				"document", "focus", "losing_focus",
				"motion_track", "html_event"):
			callback = self.__cnv(handler)
			return _gtk._gtk.gtk_signal_connect_after(self._o,
								  sig_name,
							callback.__call__)
		else:
			_gtk.GtkContainer.connect_after(self, sig_name,
							     handler)
	signal_connect_after = connect_after
	def freeze(self, obj=None):
		_gtkxmhtml.gtk_xmhtml_freeze(self._o)
	def thaw(self, obj=None):
		_gtkxmhtml.gtk_xmhtml_thaw(self._o)
	def source(self, source):
		_gtkxmhtml.gtk_xmhtml_source(self._o, source)
	def set_string_direction(self, direction):
		_gtkxmhtml.gtk_xmhtml_set_string_direction(self._o, direction)
	def set_alignment(self, alignment):
		_gtkxmhtml.gtk_xmhtml_set_alignment(self._o, alignment)
	#def outline(self, flag):
	#	_gtkxmhtml.gtk_xmhtml_outline(self._o, flag)
	# these are spelt wrong in the library ...
	def set_font_family(self, family, sizes):
		_gtkxmhtml.gtk_xmhtml_set_font_familty(self._o, family, sizes)
	def set_font_family_fixed(self, family, sizes):
		_gtkxmhtml.gtk_xmhtml_set_font_familty_fixed(self._o, family,
							    sizes)
	def set_font_charset(self, charset):
		_gtkxmhtml.gtk_xmhtml_set_font_charset(self._o, charset)
	def set_allow_body_colors(self, enable):
		_gtkxmhtml.gtk_xmhtml_set_allow_body_colors(self._o, enable)
	def set_hilight_on_enter(self, flag):
		_gtkxmhtml.gtk_xmhtml_set_hilight_on_enter(self._o, flag)
	def set_anchor_visited_underline_type(self, underline_type):
		_gtkxmhtml.gtk_xmhtml_set_anchor_visited_underline_type(
			self._o, underline_type)
	def set_anchor_target_underline_type(self, underline_type):
		_gtkxmhtml.gtk_xmhtml_set_anchor_target_underline_type(self._o,
							underline_type)
	def set_allow_color_switching(self, flag):
		_gtkxmhtml.gtk_xmhtml_set_allow_color_switching(self._o, flag)
	def set_dithering(self, dither_type):
		_gtkxmhtml.gtk_xmhtml_set_dithering(self._o, dither_type)
	def set_allow_font_switching(self, flag):
		_gtkxmhtml.gtk_xmhtml_set_allow_font_switching(self._o, flag)
	def set_max_image_colors(self, max_colors):
		_gtkxmhtml.gtk_xmhtml_set_max_image_colors(self._o, max_colors)
	def set_allow_images(self, flag):
		_gtkxmhtml.gtk_xmhtml_set_allow_images(self._o, flag)
	def set_plc_intervals(self, min_delay, max_delay, def_delay):
		_gtkxmhtml.gtk_xmhtml_set_plc_intervals(self._o, min_delay,
							max_delay, def_delay)
	def set_def_body_image_url(self, url):
		_gtkxmhtml.gtk_xmhtml_set_def_body_image_url(self._o, url)
	def set_anchor_buttons(self, flag):
		_gtkxmhtml.gtk_xmhtml_set_anchor_buttons(self._o, flag)
	def set_anchor_cursor(self, cursor, flag):
		_gtkxmhtml.gtk_xmhtml_set_anchor_cursor(self._o, cursor, flag)
	def set_topline(self, line):
		_gtkxmhtml.gtk_xmhtml_set_topline(self._o, line)
	def get_topline(self):
		return _gtkxmhtml.gtk_xmhtml_get_topline(self._o)
	def set_freeze_animations(self, flag):
		_gtkxmhtml.gtk_xmhtml_set_freeze_animations(self._o, flag)
	#def get_source(self):
	#	return _gtkxmhtml.gtk_xmhtml_get_source(self._o)
	def set_screen_gamma(self, gamma):
		_gtkxmhtml.gtk_xmhtml_set_screen_gamma(self._o, gamma)
	def set_perfect_colors(self, flag):
		_gtkxmhtml.gtk_xmhtml_set_perfect_colors(self._o, flag)
	def set_uncompress_command(self, cmd):
		_gtkxmhtml.gtk_xmhtml_set_uncompress_command(self._o, cmd)
	def set_strict_checking(self, flag):
		_gtkxmhtml.gtk_xmhtml_set_strict_checking(self._o, flag)
	def set_bad_html_warnings(self, flag):
		_gtkxmhtml.gtk_xmhtml_set_bad_html_warnings(self._o, flag)
	def set_allow_form_coloring(self, flag):
		_gtkxmhtml.gtk_xmhtml_set_allow_form_coloring(self._o, flag)
	def set_imagemap_draw(self, flag):
		_gtkxmhtml.gtk_xmhtml_set_imagemap_draw(self._o, flag)
	def set_mime_type(self, mime_type):
		_gtkxmhtml.gtk_xmhtml_set_mime_type(self._o, mime_type)
	def set_alpha_processing(self, flag):
		_gtkxmhtml.gtk_xmhtml_set_alpha_processing(self._o, flag)
	def set_rgb_conv_mode(self, val):
		_gtkxmhtml.gtk_xmhtml_set_rgb_conv_mode(self._o, val)

# this adds the GtkXmHTML class to the low level to class conversion hash:
_gtk._name2cls['GtkXmHTML'] = GtkXmHTML



import _gnome, gnome

if not gnome.gnomelib_init_called:
	_gnome.gnomelib_init(gnome.app_id, gnome.app_version)
	gnome.gnomelib_init_called = 1

# on write errors for the metadata, an IOError exception is thrown
# on metadata not found errors, an KeyError exception is thrown

def set(file, key, value):
	_gnome.gnome_metadata_set(file, key, value)
def remove(file, key):
	_gnome.gnome_metadata_remove(file, key)
def list(file):
	return _gnome.gnome_metadata_list(file)
def get(file, key):
	return _gnome.gnome_metadata_get(file, key)
def get_fast(file, key):
	return _gnome.gnome_metadata_get_fast(file, key)
def rename(file, to):
	_gnome.gnome_metadata_rename(file, to)
def copy(file, to):
	_gnome.gnome_metadata_copy(file, to)
def delete(file):
	_gnome.gnome_metadata_delete(file)
def regex_add(regex, key, value):
	_gnome.gnome_metadata_regex_add(regex, key, value)
def regex_remove(regex, key):
	_gnome.gnome_metadata_regex_remove(regex, key)
def type_add(type, key, value):
	_gnome.gnome_metadata_type_add(type, key, value)
def type_remove(type, key):
	_gnome.gnome_metadata_type_remove(type, key)
def lock():
	_gnome.gnome_metadata_lock()
def unlock():
	_gnome.gnome_metadata_unlock()



#!/usr/bin/env python
# to run this script type:
# zterm.py [prog [args ...]]
# if no program name given, spawm a python interpreter

import sys
if sys.version[:3] == '1.4':
	import ni
from gtk import *
from gnome.zvt import *
import os

def child_died_event(zvt):
	sys.exit(0)

def main():
	font_name = "-misc-fixed-medium-r-normal--20-200-75-75-c-100-*-*"

	win = GtkWindow()
	win.connect("delete_event", mainquit)
	win.set_title("ZTerm")
	win.set_policy(FALSE, TRUE, TRUE);

	hbox = GtkHBox()
	win.add(hbox)
	hbox.show()
	
	term = ZvtTerm(80, 25)
	term.set_scrollback(50)
	term.set_font_name(font_name);
	term.connect("child_died", child_died_event)
	hbox.pack_start(term)
	term.show()

	scroll = GtkVScrollbar(term.adjustment)
	hbox.pack_start(scroll, expand=FALSE)
	scroll.show()

	charwidth = term.charwidth
	charheight = term.charheight
	win.set_geometry_hints(geometry_widget=term,
			       min_width=2*charwidth, min_height=2*charheight,
			       base_width=charwidth,  base_height=charheight,
			       width_inc=charwidth,   height_inc=charheight)
	win.show()

	pid = term.forkpty()
	if pid == -1:
		print "Couldn't fork"
		sys.exit(1)
	if pid == 0:
		argv = sys.argv[1:]
		if not argv:
			os.execv('/usr/bin/env', ['/usr/bin/env', 'python'])
		else:
			os.execvp(argv[0], argv)
		print "Couldn't exec"
		os._exit(1)
	# this is executed by parent process only:
	mainloop()

if __name__ == '__main__': main()




import sys
if sys.version[:3] == '1.4':
	import ni

from gtk import *
from gnome.ui import *

def message_dlg_clicked(widget, button):
	if button == 0:
		mainquit()

def message_dlg(widget, event=None):
	box = GnomeMessageBox("Reallly quit?", "question",
			      STOCK_BUTTON_YES, STOCK_BUTTON_NO)
	box.connect("clicked", message_dlg_clicked)
	box.set_modal(TRUE)
	box.show()
	return TRUE

def prop_apply(box, n):
	if n != -1:
		mbox = GnomeMessageBox("Applied changes on page #%d" % (n,),
				       "info", STOCK_BUTTON_OK)
		mbox.show()

def prop_dlg(widget):
	box = GnomePropertyBox()
	w = GtkButton("Click me (Page #1)")
	w.connect("clicked", box.changed)
	w.show()
	label = GtkLabel("Page #1")
	label.show()
	box.append_page(w, label)
	w = GtkButton("Click me (Page #2)")
	w.connect("clicked", box.changed)
	w.show()
	label = GtkLabel("Page #2")
	label.show()
	box.append_page(w, label)
	box.connect('apply', prop_apply)
	box.show()

def create_menu():
	file_menu = [
		UIINFO_ITEM_STOCK('New...', None, None, STOCK_MENU_NEW),
		UIINFO_ITEM_STOCK('Open...', None, None, STOCK_MENU_OPEN),
		UIINFO_ITEM_STOCK('Save', None, None, STOCK_MENU_SAVE),
		UIINFO_ITEM_STOCK('Save as...', None, None, STOCK_MENU_SAVE_AS),
		UIINFO_SEPARATOR,
		UIINFO_ITEM_STOCK('Print...', None, None, STOCK_MENU_PRINT),
		UIINFO_ITEM_STOCK('Setup Page...', None, None, STOCK_MENU_BLANK),
		UIINFO_SEPARATOR,
		UIINFO_ITEM_STOCK('Quit', None, message_dlg, STOCK_MENU_QUIT)
	]
	edit_menu = [
		UIINFO_ITEM_STOCK('Undo', None, None, STOCK_MENU_UNDO),
		UIINFO_ITEM_STOCK('Redo', None, None, STOCK_MENU_BLANK),
		UIINFO_SEPARATOR,
		UIINFO_ITEM_STOCK('Delete', None, None, STOCK_MENU_BLANK),
		UIINFO_ITEM_STOCK('Cut', None, None, STOCK_MENU_CUT),
		UIINFO_ITEM_STOCK('Copy', None, None, STOCK_MENU_COPY),
		UIINFO_ITEM_STOCK('Paste', None, None, STOCK_MENU_PASTE),
		UIINFO_SEPARATOR,
		UIINFO_ITEM_STOCK('Properties...', None, prop_dlg, STOCK_MENU_PROP),
		UIINFO_ITEM_STOCK('Preferences...', None, None, STOCK_MENU_PREF),
		UIINFO_SEPARATOR,
		UIINFO_ITEM_STOCK('Scores...', None, None, STOCK_MENU_SCORES)
	]
	help_menu = [
		UIINFO_ITEM_STOCK('About', None, None, STOCK_MENU_ABOUT)
	]
	menu_info = [
		UIINFO_SUBTREE('File', file_menu),
		UIINFO_SUBTREE('Edit', edit_menu),
		UIINFO_SUBTREE('Help', help_menu)
	]
	return menu_info

def create_toolbar():
	toolbar_info = [
		UIINFO_ITEM_STOCK('New', None, None, STOCK_PIXMAP_NEW),
		UIINFO_SEPARATOR,
		UIINFO_ITEM_STOCK('Open', None, None, STOCK_PIXMAP_OPEN),
		UIINFO_ITEM_STOCK('Save', None, None, STOCK_PIXMAP_SAVE),
		UIINFO_ITEM_STOCK('Save as', None, None, STOCK_PIXMAP_SAVE_AS),
		UIINFO_SEPARATOR,
		UIINFO_ITEM_STOCK('Cut', None, None, STOCK_PIXMAP_CUT),
		UIINFO_ITEM_STOCK('Copy', None, None, STOCK_PIXMAP_COPY),
		UIINFO_ITEM_STOCK('Paste', None, None, STOCK_PIXMAP_PASTE),
		UIINFO_SEPARATOR,
		UIINFO_ITEM_STOCK('Props', None, prop_dlg, STOCK_PIXMAP_PROPERTIES)
	]
	return toolbar_info

def toggle_button(button):
	wid = button.children()[0]
	text = button.get_data('user_data')
	if text == STOCK_PIXMAP_TIMER_STOP:
		wid.set_icon(STOCK_PIXMAP_TIMER)
		button.set_data('user_data', STOCK_PIXMAP_TIMER)
	else:
		wid.set_icon(STOCK_PIXMAP_TIMER_STOP)
		button.set_data('user_data', STOCK_PIXMAP_TIMER_STOP)

def fill_table(win, table):
	w = GnomeStock(STOCK_PIXMAP_HELP)
	w.show()
	table.attach(w, 0,1, 0,1)
	w = GtkLabel("Help")
	w.show()
	table.attach(w, 0,1, 2,3)

	w = GnomeStock(STOCK_PIXMAP_SEARCH)
	w.show()
	table.attach(w, 1,2, 0,1)
	w = GnomeStock(STOCK_MENU_SEARCH)
	w.show()
	table.attach(w, 1,2, 1,2)
	w = GtkLabel('Search')
	w.show()
	table.attach(w, 1,2, 2,3)

	w = GnomeStock(STOCK_PIXMAP_PRINT)
	w.show()
	table.attach(w, 2,3, 0,1)
	w = GtkLabel('Print')
	w.show()
	table.attach(w, 2,3, 2,3)

	w = GnomeStock(STOCK_PIXMAP_BACK)
	w.show()
	table.attach(w, 3,4, 0,1)
	w = GnomeStock(STOCK_MENU_BACK)
	w.show()
	table.attach(w, 3,4, 1,2)
	w = GtkLabel('Backward')
	w.show()
	table.attach(w, 3,4, 2,3)

	w = GnomeStock(STOCK_PIXMAP_FORWARD)
	w.show()
	table.attach(w, 4,5, 0,1)
	w = GnomeStock(STOCK_MENU_FORWARD)
	w.show()
	table.attach(w, 4,5, 1,2)
	w = GtkLabel('Forward')
	w.show()
	table.attach(w, 4,5, 2,3)

	w = GnomeStock(STOCK_PIXMAP_PREFERENCES)
	w.show()
	table.attach(w, 5,6, 0,1)
	w = GtkLabel('Preferences')
	w.show()
	table.attach(w, 5,6, 2,3)

	button = GtkButton()
	wid = GnomeStock(STOCK_PIXMAP_TIMER_STOP)
	wid.show()
	button.add(wid)
	button.show()
	table.attach(button, 0,1, 3,4)
	button.connect('clicked', toggle_button)
	button.set_data('user_data', STOCK_PIXMAP_TIMER_STOP)

	button = GtkButton()
	wid = GnomeStock(STOCK_PIXMAP_TIMER)
	wid.show()
	button.add(wid)
	button.show()
	table.attach(button, 0,1, 3,4)
	button.connect('clicked', toggle_button)
	button.set_data('user_data', STOCK_PIXMAP_TIMER)

	w = GnomeStock(STOCK_PIXMAP_MAIL)
	w.show()
	table.attach(w, 2,3, 3,4)
	w = GnomeStock(STOCK_MENU_MAIL)
	w.show()
	table.attach(w, 2,3, 4,5)
	w = GtkLabel('Mail')
	w.show()
	table.attach(w, 2,3, 5,6)

	w = GnomeStock(STOCK_PIXMAP_MAIL_RCV)
	w.show()
	table.attach(w, 3,4, 3,4)
	w = GnomeStock(STOCK_MENU_MAIL_RCV)
	w.show()
	table.attach(w, 3,4, 4,5)
	w = GtkLabel('Receive Mail')
	w.show()
	table.attach(w, 3,4, 5,6)

	w = GnomeStock(STOCK_PIXMAP_MAIL_SND)
	w.show()
	table.attach(w, 4,5, 3,4)
	w = GnomeStock(STOCK_MENU_MAIL_SND)
	w.show()
	table.attach(w, 4,5, 4,5)
	w = GtkLabel('Send Mail')
	w.show()
	table.attach(w, 4,5, 5,6)

def main():
	win = GnomeApp('stock_demo', 'PyGnome Stock Test')
	win.set_wmclass('stock_test', 'PyGnomeStockTest')
	win.connect('delete_event', message_dlg)
	win.connect('destroy', mainquit)

	win.create_menus(create_menu())
	win.create_toolbar(create_toolbar())

	vbox = GtkVBox(spacing=5)
	vbox.set_border_width(5)
	vbox.show()
	frame = GtkFrame("Other Icons")
	frame.show()
	vbox.pack_start(frame)
	table = GtkTable(1, 1, FALSE)
	table.set_border_width(3)
	table.show()
	frame.add(table)
	fill_table(win, table)

	hbox = GtkHBox(spacing=3)
	hbox.show()
	vbox.pack_end(hbox, expand=FALSE)

	w = GnomeStockButton(STOCK_BUTTON_OK)
	w.show()
	hbox.pack_start(w, fill=FALSE)
	w = GnomeStockButton(STOCK_BUTTON_APPLY)
	w.show()
	hbox.pack_start(w, fill=FALSE)
	w = GnomeStockButton(STOCK_BUTTON_CANCEL)
	w.show()
	hbox.pack_start(w, fill=FALSE)
	w = GnomeStockButton(STOCK_BUTTON_YES)
	w.show()
	hbox.pack_start(w, fill=FALSE)
	w = GnomeStockButton(STOCK_BUTTON_NO)
	w.show()
	hbox.pack_start(w, fill=FALSE)
	w = GnomeStockButton(STOCK_BUTTON_HELP)
	w.show()
	hbox.pack_start(w, fill=FALSE)
	w = GnomeStockButton(STOCK_BUTTON_CLOSE)
	w.show()
	w.connect('clicked', message_dlg)
	hbox.pack_start(w, fill=FALSE)
	

	win.set_contents(vbox)
	win.show()
	mainloop()

if __name__ == '__main__': main()



# python-gnome-colorpicker
# Vincent Renardias <vincent@ldsol.com>, 1999/09/10

from gtk import *
from gnome.ui import *
from GDK import *

window = GtkWindow(type='toplevel')
window.connect('destroy', mainquit)
window.set_usize(50, 50)

color = GnomeColorPicker()
window.add(color)

window.show_all()

mainloop()




import _gnome, gnome

if not gnome.gnomelib_init_called:
	_gnome.gnomelib_init(gnome.app_id, gnome.app_version)
	gnome.gnomelib_init_called = 1

def get_string(path):
	return _gnome.gnome_config_get_string(path)
def get_translated_string(path):
	return _gnome.gnome_config_get_translated_string(path)
def get_int(path):
	return _gnome.gnome_config_get_int(path)
def get_float(path):
	return _gnome.gnome_config_get_float(path)
def get_bool(path):
	return _gnome.gnome_config_get_bool(path)
def get_vector(path):
	return _gnome.gnome_config_get_vector(path)
def set_string(path, val):
	_gnome.gnome_config_set_string(path, val)
def set_translated_string(path, val):
	_gnome.gnome_config_set_translated_string(path, val)
def set_int(path, val):
	_gnome.gnome_config_set_int(path, val)
def set_float(path, val):
	_gnome.gnome_config_set_float(path, val)
def set_bool(path, val):
	_gnome.gnome_config_set_bool(path, val)
def set_vector(path, val):
	_gnome.gnome_config_set_vector(path, val)

def has_section(path):
	return _gnome.gnome_config_has_section(path)
def section_contents(path):
	return _gnome.gnome_config_section_contents(path)
def enum_sections(path):
	return _gnome.gnome_config_enum_sections(path)

def private_get_string(path):
	return _gnome.gnome_config_private_get_string(path)
def private_get_translated_string(path):
	return _gnome.gnome_config_private_get_translated_string(path)
def private_get_int(path):
	return _gnome.gnome_config_private_get_int(path)
def private_get_float(path):
	return _gnome.gnome_config_private_get_float(path)
def private_get_bool(path):
	return _gnome.gnome_config_private_get_bool(path)
def private_get_vector(path):
	return _gnome.gnome_config_private_get_vector(path)
def private_set_string(path, val):
	_gnome.gnome_config_private_set_string(path, val)
def private_set_translated_string(path, val):
	_gnome.gnome_config_private_set_translated_string(path, val)
def private_set_int(path, val):
	_gnome.gnome_config_private_set_int(path, val)
def private_set_float(path, val):
	_gnome.gnome_config_private_set_float(path,val)
def private_set_bool(path, val):
	_gnome.gnome_config_private_set_bool(path, val)
def private_set_vector(path, val):
	_gnome.gnome_config_private_set_vector(path, val)

def private_has_section(path):
	return _gnome.gnome_config_private_has_section(path)
def private_section_contents(path):
	return _gnome.gnome_config_private_section_contents(path)
def private_enum_sections(path):
	return _gnome.gnome_config_private_enum_sections(path)

def drop_all():
	_gnome.gnome_config_drop_all()
def sync():
	_gnome.gnome_config_sync()

def sync_file(path):
	_gnome.gnome_config_sync_file(path)
def private_sync_file(path):
	_gnome.gnome_config_private_sync_file(path)

def drop_file(path):
	_gnome.gnome_config_drop_file(path)
def clean_file(path):
	_gnome.gnome_config_clean_file(path)
def clean_section(path):
	_gnome.gnome_config_clean_section(path)
def clean_key(path):
	_gnome.gnome_config_clean_key(path)
def private_drop_file(path):
	_gnome.gnome_config_private_drop_file(path)
def private_clean_file(path):
	_gnome.gnome_config_private_clean_file(path)
def private_clean_section(path):
	_gnome.gnome_config_private_clean_section(path)
def private_clean_key(path):
	_gnome.gnome_config_private_clean_key(path)

def push_prefix(path):
	_gnome.gnome_config_push_prefix(path)
def pop_prefix():
	_gnome.gnome_config_pop_prefix()



from gtk import *
from gnome.ui import *

win = GtkWindow()
win.connect('destroy', mainquit)
win.set_title('Canvas test')

canvas = GnomeCanvas()
canvas.set_size(300, 300)
win.add(canvas)
canvas.show()

canvas.root().add('line', points=(10,10, 90,10, 90,90, 10,90),
		  width_pixels=10, fill_color='blue')

win.show()

mainloop()

